# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_publishedfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_productinfo_pb2 as enums__productinfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_publishedfile.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x17\x65nums_productinfo.proto\"G\n\x1b\x43PublishedFile_Vote_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\"\x1e\n\x1c\x43PublishedFile_Vote_Response\"\x92\x01\n CPublishedFile_Subscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\x12\x1c\n\x14include_dependencies\x18\x05 \x01(\x08\"#\n!CPublishedFile_Subscribe_Response\"v\n\"CPublishedFile_Unsubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\x05\x12\x15\n\rnotify_client\x18\x04 \x01(\x08\"%\n#CPublishedFile_Unsubscribe_Response\">\n#CPublishedFile_CanSubscribe_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"=\n$CPublishedFile_CanSubscribe_Response\x12\x15\n\rcan_subscribe\x18\x01 \x01(\x08\"\xd3\x01\n(CPublishedFile_GetSubSectionData_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x66or_table_of_contents\x18\x02 \x01(\x08\x12\x1a\n\x12specific_sectionid\x18\x03 \x01(\x04\x12S\n\x10\x64\x65sired_revision\x18\x04 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"i\n\x17PublishedFileSubSection\x12\x11\n\tsectionid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65scription_text\x18\x03 \x01(\t\x12\x12\n\nsort_order\x18\x04 \x01(\r\"[\n)CPublishedFile_GetSubSectionData_Response\x12.\n\x0csub_sections\x18\x01 \x03(\x0b\x32\x18.PublishedFileSubSection\"\xfd\x02\n\x1e\x43PublishedFile_Publish_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x16\n\x0e\x63onsumer_appid\x18\x02 \x01(\r\x12\x15\n\rcloudfilename\x18\x03 \x01(\t\x12\x1d\n\x15preview_cloudfilename\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x06 \x01(\t\x12\x11\n\tfile_type\x18\x07 \x01(\r\x12\x1e\n\x16\x63onsumer_shortcut_name\x18\x08 \x01(\t\x12\x18\n\x10youtube_username\x18\t \x01(\t\x12\x17\n\x0fyoutube_videoid\x18\n \x01(\t\x12\x12\n\nvisibility\x18\x0b \x01(\r\x12\x14\n\x0credirect_uri\x18\x0c \x01(\t\x12\x0c\n\x04tags\x18\r \x03(\t\x12\x17\n\x0f\x63ollection_type\x18\x0e \x01(\t\x12\x11\n\tgame_type\x18\x0f \x01(\t\x12\x0b\n\x03url\x18\x10 \x01(\t\"P\n\x1f\x43PublishedFile_Publish_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\xfb\x03\n!CPublishedFile_GetDetails_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x06\x12\x13\n\x0bincludetags\x18\x02 \x01(\x08\x12!\n\x19includeadditionalpreviews\x18\x03 \x01(\x08\x12\x17\n\x0fincludechildren\x18\x04 \x01(\x08\x12\x15\n\rincludekvtags\x18\x05 \x01(\x08\x12\x14\n\x0cincludevotes\x18\x06 \x01(\x08\x12\x19\n\x11short_description\x18\x08 \x01(\x08\x12\x1a\n\x12includeforsaledata\x18\n \x01(\x08\x12\x17\n\x0fincludemetadata\x18\x0b \x01(\x08\x12\x13\n\x08language\x18\x0c \x01(\x05:\x01\x30\x12\x1d\n\x15return_playtime_stats\x18\r \x01(\r\x12\r\n\x05\x61ppid\x18\x0e \x01(\r\x12 \n\x18strip_description_bbcode\x18\x0f \x01(\x08\x12S\n\x10\x64\x65sired_revision\x18\x10 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x1f\n\x10includereactions\x18\x11 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0b\x61\x64min_query\x18\x12 \x01(\x08\"v\n\x1bPublishedFileAuthorSnapshot\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x17\n\x0fgame_branch_min\x18\x02 \x01(\t\x12\x17\n\x0fgame_branch_max\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x06\"\x8a\x17\n\x14PublishedFileDetails\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x03 \x01(\x06\x12\x15\n\rcreator_appid\x18\x04 \x01(\r\x12\x16\n\x0e\x63onsumer_appid\x18\x05 \x01(\r\x12\x1b\n\x13\x63onsumer_shortcutid\x18\x06 \x01(\r\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x11\n\tfile_size\x18\x08 \x01(\x04\x12\x19\n\x11preview_file_size\x18\t \x01(\x04\x12\x10\n\x08\x66ile_url\x18\n \x01(\t\x12\x13\n\x0bpreview_url\x18\x0b \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x0c \x01(\t\x12\x0b\n\x03url\x18\r \x01(\t\x12\x15\n\rhcontent_file\x18\x0e \x01(\x06\x12\x18\n\x10hcontent_preview\x18\x0f \x01(\x06\x12\r\n\x05title\x18\x10 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x11 \x01(\t\x12\x19\n\x11short_description\x18\x12 \x01(\t\x12\x14\n\x0ctime_created\x18\x13 \x01(\r\x12\x14\n\x0ctime_updated\x18\x14 \x01(\r\x12\x12\n\nvisibility\x18\x15 \x01(\r\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x15\n\rworkshop_file\x18\x17 \x01(\x08\x12\x19\n\x11workshop_accepted\x18\x18 \x01(\x08\x12\x1a\n\x12show_subscribe_all\x18\x19 \x01(\x08\x12\x1e\n\x16num_comments_developer\x18\x1a \x01(\x05\x12\x1b\n\x13num_comments_public\x18\x1b \x01(\x05\x12\x0e\n\x06\x62\x61nned\x18\x1c \x01(\x08\x12\x12\n\nban_reason\x18\x1d \x01(\t\x12\x0e\n\x06\x62\x61nner\x18\x1e \x01(\x06\x12\x16\n\x0e\x63\x61n_be_deleted\x18\x1f \x01(\x08\x12\x14\n\x0cincompatible\x18  \x01(\x08\x12\x10\n\x08\x61pp_name\x18! \x01(\t\x12\x11\n\tfile_type\x18\" \x01(\r\x12\x15\n\rcan_subscribe\x18# \x01(\x08\x12\x15\n\rsubscriptions\x18$ \x01(\r\x12\x11\n\tfavorited\x18% \x01(\r\x12\x11\n\tfollowers\x18& \x01(\r\x12\x1e\n\x16lifetime_subscriptions\x18\' \x01(\r\x12\x1a\n\x12lifetime_favorited\x18( \x01(\r\x12\x1a\n\x12lifetime_followers\x18) \x01(\r\x12\x19\n\x11lifetime_playtime\x18> \x01(\x04\x12\"\n\x1alifetime_playtime_sessions\x18? \x01(\x04\x12\r\n\x05views\x18* \x01(\r\x12\x13\n\x0bimage_width\x18+ \x01(\r\x12\x14\n\x0cimage_height\x18, \x01(\r\x12\x11\n\timage_url\x18- \x01(\t\x12\x13\n\x0bspoiler_tag\x18. \x01(\x08\x12\x12\n\nshortcutid\x18/ \x01(\r\x12\x14\n\x0cshortcutname\x18\x30 \x01(\t\x12\x14\n\x0cnum_children\x18\x31 \x01(\r\x12\x13\n\x0bnum_reports\x18\x32 \x01(\r\x12/\n\x08previews\x18\x33 \x03(\x0b\x32\x1d.PublishedFileDetails.Preview\x12\'\n\x04tags\x18\x34 \x03(\x0b\x32\x19.PublishedFileDetails.Tag\x12-\n\x08\x63hildren\x18\x35 \x03(\x0b\x32\x1b.PublishedFileDetails.Child\x12+\n\x06kvtags\x18\x36 \x03(\x0b\x32\x1b.PublishedFileDetails.KVTag\x12\x31\n\tvote_data\x18\x37 \x01(\x0b\x32\x1e.PublishedFileDetails.VoteData\x12;\n\x0eplaytime_stats\x18@ \x01(\x0b\x32#.PublishedFileDetails.PlaytimeStats\x12\x17\n\x0ftime_subscribed\x18\x38 \x01(\r\x12\x38\n\rfor_sale_data\x18\x39 \x01(\x0b\x32!.PublishedFileDetails.ForSaleData\x12\x10\n\x08metadata\x18: \x01(\t\x12\x13\n\x08language\x18= \x01(\x05:\x01\x30\x12\x1f\n\x17maybe_inappropriate_sex\x18\x41 \x01(\x08\x12$\n\x1cmaybe_inappropriate_violence\x18\x42 \x01(\x08\x12\x34\n\x15\x63ontent_descriptorids\x18H \x03(\x0e\x32\x15.EContentDescriptorID\x12\x1e\n\x16revision_change_number\x18\x43 \x01(\x04\x12K\n\x08revision\x18\x44 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x34\n\x13\x61vailable_revisions\x18\x45 \x03(\x0e\x32\x17.EPublishedFileRevision\x12\x31\n\treactions\x18\x46 \x03(\x0b\x32\x1e.PublishedFileDetails.Reaction\x12[\n\x15\x62\x61n_text_check_result\x18G \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\x12\x14\n\x0csearch_score\x18I \x01(\x02\x12\x19\n\x11\x65xternal_asset_id\x18J \x01(\x04\x12\x36\n\x10\x61uthor_snapshots\x18K \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\x1a;\n\x03Tag\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x11\n\tadminonly\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x1a\xa6\x01\n\x07Preview\x12\x11\n\tpreviewid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x10\n\x08\x66ilename\x18\x05 \x01(\t\x12\x16\n\x0eyoutubevideoid\x18\x06 \x01(\t\x12\x14\n\x0cpreview_type\x18\x07 \x01(\r\x12\x1a\n\x12\x65xternal_reference\x18\x08 \x01(\t\x1a\x46\n\x05\x43hild\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x11\n\tsortorder\x18\x02 \x01(\r\x12\x11\n\tfile_type\x18\x03 \x01(\r\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x8c\x01\n\x08VoteData\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x10\n\x08votes_up\x18\x02 \x01(\r\x12\x12\n\nvotes_down\x18\x03 \x01(\r\x12\x15\n\rtrusted_score\x18\x04 \x01(\x02\x12\x18\n\x10trusted_votes_up\x18\x05 \x01(\r\x12\x1a\n\x12trusted_votes_down\x18\x06 \x01(\r\x1a\xdc\x01\n\x0b\x46orSaleData\x12\x13\n\x0bis_for_sale\x18\x01 \x01(\x08\x12\x16\n\x0eprice_category\x18\x02 \x01(\r\x12\x41\n\x07\x65status\x18\x03 \x01(\x0e\x32\x1c.EPublishedFileForSaleStatus:\x12k_PFFSS_NotForSale\x12\x1c\n\x14price_category_floor\x18\x04 \x01(\r\x12\"\n\x1aprice_is_pay_what_you_want\x18\x05 \x01(\x08\x12\x1b\n\x13\x64iscount_percentage\x18\x06 \x01(\r\x1a?\n\rPlaytimeStats\x12\x18\n\x10playtime_seconds\x18\x01 \x01(\x04\x12\x14\n\x0cnum_sessions\x18\x02 \x01(\x04\x1a-\n\x08Reaction\x12\x12\n\nreactionid\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"Y\n\"CPublishedFile_GetDetails_Response\x12\x33\n\x14publishedfiledetails\x18\x01 \x03(\x0b\x32\x15.PublishedFileDetails\"\xaf\x02\n\"CPublishedFile_GetItemInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12H\n\x0eworkshop_items\x18\x03 \x03(\x0b\x32\x30.CPublishedFile_GetItemInfo_Request.WorkshopItem\x1a\x94\x01\n\x0cWorkshopItem\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x03 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"\x8f\x03\n#CPublishedFile_GetItemInfo_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12M\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x35.CPublishedFile_GetItemInfo_Response.WorkshopItemInfo\x12\x15\n\rprivate_items\x18\x03 \x03(\x06\x1a\xec\x01\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12K\n\x08revision\x18\x05 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x36\n\x10\x61uthor_snapshots\x18\x06 \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\"\x86\t\n#CPublishedFile_GetUserFiles_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x12\n\nshortcutid\x18\x03 \x01(\r\x12\x0f\n\x04page\x18\x04 \x01(\r:\x01\x31\x12\x15\n\nnumperpage\x18\x05 \x01(\r:\x01\x31\x12\x15\n\x04type\x18\x06 \x01(\t:\x07myfiles\x12\x1f\n\nsortmethod\x18\x07 \x01(\t:\x0blastupdated\x12\x0f\n\x07privacy\x18\t \x01(\r\x12\x14\n\x0crequiredtags\x18\n \x03(\t\x12\x14\n\x0c\x65xcludedtags\x18\x0b \x03(\t\x12\x44\n\x10required_kv_tags\x18\x1e \x03(\x0b\x32*.CPublishedFile_GetUserFiles_Request.KVTag\x12\x10\n\x08\x66iletype\x18\x0e \x01(\r\x12\x15\n\rcreator_appid\x18\x0f \x01(\r\x12\x1c\n\x14match_cloud_filename\x18\x10 \x01(\t\x12 \n\x15\x63\x61\x63he_max_age_seconds\x18\x1b \x01(\r:\x01\x30\x12\x13\n\x08language\x18\x1d \x01(\x05:\x01\x30\x12@\n\ttaggroups\x18\" \x03(\x0b\x32-.CPublishedFile_GetUserFiles_Request.TagGroup\x12;\n\x1c\x65xcluded_content_descriptors\x18% \x03(\x0e\x32\x15.EContentDescriptorID\x12\x13\n\x0b\x61\x64min_query\x18& \x01(\x08\x12\x11\n\ttotalonly\x18\x11 \x01(\x08\x12\x10\n\x08ids_only\x18\x12 \x01(\x08\x12\x1e\n\x10return_vote_data\x18\x13 \x01(\x08:\x04true\x12\x13\n\x0breturn_tags\x18\x14 \x01(\x08\x12\x1c\n\x0ereturn_kv_tags\x18\x15 \x01(\x08:\x04true\x12\x17\n\x0freturn_previews\x18\x16 \x01(\x08\x12\x17\n\x0freturn_children\x18\x17 \x01(\x08\x12&\n\x18return_short_description\x18\x18 \x01(\x08:\x04true\x12\x1c\n\x14return_for_sale_data\x18\x1a \x01(\x08\x12\x1e\n\x0freturn_metadata\x18\x1c \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x15return_playtime_stats\x18\x1f \x01(\r\x12 \n\x18strip_description_bbcode\x18  \x01(\x08\x12\x1f\n\x10return_reactions\x18# \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13startindex_override\x18\x19 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18! \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x13\n\x0breturn_apps\x18$ \x01(\x08\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\"\x80\x02\n$CPublishedFile_GetUserFiles_Response\x12\r\n\x05total\x18\x01 \x01(\r\x12\x12\n\nstartindex\x18\x02 \x01(\r\x12\x33\n\x14publishedfiledetails\x18\x03 \x03(\x0b\x32\x15.PublishedFileDetails\x12\x37\n\x04\x61pps\x18\x04 \x03(\x0b\x32).CPublishedFile_GetUserFiles_Response.App\x1aG\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nshortcutid\x18\x03 \x01(\r\x12\x0f\n\x07private\x18\x04 \x01(\x08\"\x9a\x01\n1CPublishedFile_AreFilesInSubscriptionList_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x06\x12\x10\n\x08listtype\x18\x03 \x01(\r\x12\x10\n\x08\x66iletype\x18\x04 \x01(\r\x12\x18\n\x10workshopfiletype\x18\x05 \x01(\r\"\xb2\x01\n2CPublishedFile_AreFilesInSubscriptionList_Response\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.CPublishedFile_AreFilesInSubscriptionList_Response.InList\x1a\x31\n\x06InList\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x0e\n\x06inlist\x18\x02 \x01(\x08\"\x90\x02\n\x1d\x43PublishedFile_Update_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x06\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10\x66ile_description\x18\x04 \x01(\t\x12\x12\n\nvisibility\x18\x05 \x01(\r\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x18\n\x10preview_filename\x18\x08 \x01(\t\x12\x13\n\x0bspoiler_tag\x18\n \x01(\x08\x12\x13\n\x0bimage_width\x18\x0f \x01(\r\x12\x14\n\x0cimage_height\x18\x10 \x01(\r\x12\x10\n\x08language\x18\x11 \x01(\x05\" \n\x1e\x43PublishedFile_Update_Response\"G\n\x1d\x43PublishedFile_Delete_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\" \n\x1e\x43PublishedFile_Delete_Response\"l\n,CPublishedFile_GetChangeHistoryEntry_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08language\x18\x03 \x01(\x05\"\xce\x01\n-CPublishedFile_GetChangeHistoryEntry_Response\x12\x1a\n\x12\x63hange_description\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x16\n\x0esaved_snapshot\x18\x03 \x01(\x08\x12 \n\x18snapshot_game_branch_min\x18\x04 \x01(\t\x12 \n\x18snapshot_game_branch_max\x18\x05 \x01(\t\x12\x13\n\x0bmanifest_id\x18\x06 \x01(\x06\"\x8e\x01\n\'CPublishedFile_GetChangeHistory_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x12\n\ntotal_only\x18\x02 \x01(\x08\x12\x12\n\nstartindex\x18\x03 \x01(\r\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\x13\n\x08language\x18\x05 \x01(\x05:\x01\x30\"\xbf\x02\n(CPublishedFile_GetChangeHistory_Response\x12\x44\n\x07\x63hanges\x18\x01 \x03(\x0b\x32\x33.CPublishedFile_GetChangeHistory_Response.ChangeLog\x12\r\n\x05total\x18\x02 \x01(\r\x1a\xbd\x01\n\tChangeLog\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x1a\n\x12\x63hange_description\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\x05\x12\x16\n\x0esaved_snapshot\x18\x04 \x01(\x08\x12 \n\x18snapshot_game_branch_min\x18\x05 \x01(\t\x12 \n\x18snapshot_game_branch_max\x18\x06 \x01(\t\x12\x13\n\x0bmanifest_id\x18\x07 \x01(\x06\"\x8a\x02\n)CPublishedFile_RefreshVotingQueue_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12matching_file_type\x18\x02 \x01(\r\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x1c\n\x0ematch_all_tags\x18\x04 \x01(\x08:\x04true\x12\x15\n\rexcluded_tags\x18\x05 \x03(\t\x12\x1a\n\x12\x64\x65sired_queue_size\x18\x06 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x08 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\",\n*CPublishedFile_RefreshVotingQueue_Response\"\xec\n\n!CPublishedFile_QueryFiles_Request\x12\x12\n\nquery_type\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x0e\n\x06\x63ursor\x18\' \x01(\t\x12\x15\n\nnumperpage\x18\x03 \x01(\r:\x01\x31\x12\x15\n\rcreator_appid\x18\x04 \x01(\r\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\x12\x14\n\x0crequiredtags\x18\x06 \x03(\t\x12\x14\n\x0c\x65xcludedtags\x18\x07 \x03(\t\x12\x1c\n\x0ematch_all_tags\x18\x08 \x01(\x08:\x04true\x12\x16\n\x0erequired_flags\x18\t \x03(\t\x12\x15\n\romitted_flags\x18\n \x03(\t\x12\x13\n\x0bsearch_text\x18\x0b \x01(\t\x12\x10\n\x08\x66iletype\x18\x0c \x01(\r\x12\x1d\n\x15\x63hild_publishedfileid\x18\r \x01(\x06\x12\x0c\n\x04\x64\x61ys\x18\x0e \x01(\r\x12!\n\x19include_recent_votes_only\x18\x0f \x01(\x08\x12 \n\x15\x63\x61\x63he_max_age_seconds\x18\x1f \x01(\r:\x01\x30\x12\x13\n\x08language\x18! \x01(\x05:\x01\x30\x12\x42\n\x10required_kv_tags\x18\" \x03(\x0b\x32(.CPublishedFile_QueryFiles_Request.KVTag\x12>\n\ttaggroups\x18* \x03(\x0b\x32+.CPublishedFile_QueryFiles_Request.TagGroup\x12H\n\x12\x64\x61te_range_created\x18, \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRange\x12H\n\x12\x64\x61te_range_updated\x18- \x01(\x0b\x32,.CPublishedFile_QueryFiles_Request.DateRange\x12;\n\x1c\x65xcluded_content_descriptors\x18. \x03(\x0e\x32\x15.EContentDescriptorID\x12\x13\n\x0b\x61\x64min_query\x18/ \x01(\x08\x12\x11\n\ttotalonly\x18\x10 \x01(\x08\x12\x10\n\x08ids_only\x18# \x01(\x08\x12\x18\n\x10return_vote_data\x18\x11 \x01(\x08\x12\x13\n\x0breturn_tags\x18\x12 \x01(\x08\x12\x16\n\x0ereturn_kv_tags\x18\x13 \x01(\x08\x12\x17\n\x0freturn_previews\x18\x14 \x01(\x08\x12\x17\n\x0freturn_children\x18\x15 \x01(\x08\x12 \n\x18return_short_description\x18\x16 \x01(\x08\x12\x1c\n\x14return_for_sale_data\x18\x1e \x01(\x08\x12\x1e\n\x0freturn_metadata\x18  \x01(\x08:\x05\x66\x61lse\x12\x1d\n\x15return_playtime_stats\x18$ \x01(\r\x12\x16\n\x0ereturn_details\x18% \x01(\x08\x12 \n\x18strip_description_bbcode\x18& \x01(\x08\x12S\n\x10\x64\x65sired_revision\x18( \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x1f\n\x10return_reactions\x18+ \x01(\x08:\x05\x66\x61lse\x1a#\n\x05KVTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x18\n\x08TagGroup\x12\x0c\n\x04tags\x18\x01 \x03(\t\x1a;\n\tDateRange\x12\x17\n\x0ftimestamp_start\x18\x01 \x01(\r\x12\x15\n\rtimestamp_end\x18\x02 \x01(\r\"}\n\"CPublishedFile_QueryFiles_Response\x12\r\n\x05total\x18\x01 \x01(\r\x12\x33\n\x14publishedfiledetails\x18\x02 \x03(\x0b\x32\x15.PublishedFileDetails\x12\x13\n\x0bnext_cursor\x18\x03 \x01(\t\"i\n)CPublishedFile_AddAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\",\n*CPublishedFile_AddAppRelationship_Response\"l\n,CPublishedFile_RemoveAppRelationship_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x14\n\x0crelationship\x18\x03 \x01(\r\"/\n-CPublishedFile_RemoveAppRelationship_Response\"E\n*CPublishedFile_GetAppRelationships_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"\xbe\x01\n+CPublishedFile_GetAppRelationships_Response\x12W\n\x11\x61pp_relationships\x18\x03 \x03(\x0b\x32<.CPublishedFile_GetAppRelationships_Response.AppRelationship\x1a\x36\n\x0f\x41ppRelationship\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0crelationship\x18\x02 \x01(\r\"j\n1CPublishedFile_GetAppRelationshipsBatched_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x04\x12\x1b\n\x13\x66ilter_relationship\x18\x02 \x01(\r\"\xff\x02\n2CPublishedFile_GetAppRelationshipsBatched_Response\x12g\n\rrelationships\x18\x01 \x03(\x0b\x32P.CPublishedFile_GetAppRelationshipsBatched_Response.PublishedFileAppRelationship\x1a\x36\n\x0f\x41ppRelationship\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0crelationship\x18\x02 \x01(\r\x1a\xa7\x01\n\x1cPublishedFileAppRelationship\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x0e\n\x06result\x18\x02 \x01(\r\x12^\n\x11\x61pp_relationships\x18\x03 \x03(\x0b\x32\x43.CPublishedFile_GetAppRelationshipsBatched_Response.AppRelationship\"W\n,CPublishedFile_StartPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\"/\n-CPublishedFile_StartPlaytimeTracking_Response\"V\n+CPublishedFile_StopPlaytimeTracking_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10publishedfileids\x18\x02 \x03(\x04\".\n,CPublishedFile_StopPlaytimeTracking_Response\"J\n9CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"<\n:CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\"\x81\x02\n6CPublishedFile_SetPlaytimeForControllerConfigs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12n\n\x17\x63ontroller_config_usage\x18\x02 \x03(\x0b\x32M.CPublishedFile_SetPlaytimeForControllerConfigs_Request.ControllerConfigUsage\x1aH\n\x15\x43ontrollerConfigUsage\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x16\n\x0eseconds_active\x18\x02 \x01(\x02\"9\n7CPublishedFile_SetPlaytimeForControllerConfigs_Response\"Y\n\x1f\x43PublishedFile_AddChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"\"\n CPublishedFile_AddChild_Response\"\\\n\"CPublishedFile_RemoveChild_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x12\x1d\n\x15\x63hild_publishedfileid\x18\x02 \x01(\x04\"%\n#CPublishedFile_RemoveChild_Response\"h\n,CPublishedFile_SetCollectionChildren_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x10\n\x08\x63hildren\x18\x03 \x03(\x04\"/\n-CPublishedFile_SetCollectionChildren_Response\"\x87\x01\n8CPublishedFile_SetSubscriptionListFromCollection_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tlist_type\x18\x02 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x03 \x01(\x04\x12\x10\n\x08\x61\x64\x64_only\x18\x04 \x01(\x08\";\n9CPublishedFile_SetSubscriptionListFromCollection_Response\"E\n)CPublishedFile_GetUserVoteSummary_Request\x12\x18\n\x10publishedfileids\x18\x01 \x03(\x06\"\xda\x01\n*CPublishedFile_GetUserVoteSummary_Response\x12J\n\tsummaries\x18\x01 \x03(\x0b\x32\x37.CPublishedFile_GetUserVoteSummary_Response.VoteSummary\x1a`\n\x0bVoteSummary\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x10\n\x08vote_for\x18\x02 \x01(\x08\x12\x14\n\x0cvote_against\x18\x03 \x01(\x08\x12\x10\n\x08reported\x18\x04 \x01(\x08\"\xbd\x01\n%CPublishedFile_GetItemChanges_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12\x15\n\rnum_items_max\x18\x03 \x01(\r\x12S\n\x10\x64\x65sired_revision\x18\x04 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\"\xa2\x02\n&CPublishedFile_GetItemChanges_Response\x12\x13\n\x0bupdate_time\x18\x01 \x01(\r\x12P\n\x0eworkshop_items\x18\x02 \x03(\x0b\x32\x38.CPublishedFile_GetItemChanges_Response.WorkshopItemInfo\x1a\x90\x01\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\x12\x36\n\x10\x61uthor_snapshots\x18\x04 \x03(\x0b\x32\x1c.PublishedFileAuthorSnapshot\"G\n,CPublishedFile_GetContentDescriptors_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\"\xba\x02\n-CPublishedFile_GetContentDescriptors_Response\x12]\n\x13\x63ontent_descriptors\x18\x01 \x03(\x0b\x32@.CPublishedFile_GetContentDescriptors_Response.ContentDescriptor\x1a\xa9\x01\n\x11\x43ontentDescriptor\x12W\n\x0c\x64\x65scriptorid\x18\x01 \x01(\x0e\x32\x15.EContentDescriptorID:*k_EContentDescriptor_NudityOrSexualContent\x12\x11\n\taccountid\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x15\n\rmoderator_set\x18\x04 \x01(\x08\"\xb3\x01\n/CPublishedFile_UpdateContentDescriptors_Request\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x06\x12\x31\n\x12\x64\x65scriptors_to_add\x18\x02 \x03(\x0e\x32\x15.EContentDescriptorID\x12\x34\n\x15\x64\x65scriptors_to_remove\x18\x03 \x03(\x0e\x32\x15.EContentDescriptorID\"M\n0CPublishedFile_UpdateContentDescriptors_Response\x12\x19\n\x11timestamp_updated\x18\x01 \x01(\r\"\xa4\x04\n*CPublishedFile_FileSubscribed_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x15\n\rfile_hcontent\x18\x03 \x01(\x06\x12\x11\n\tfile_size\x18\x04 \x01(\r\x12\x18\n\x10rtime_subscribed\x18\x05 \x01(\r\x12\x18\n\x10is_depot_content\x18\x06 \x01(\x08\x12\x15\n\rrtime_updated\x18\x07 \x01(\r\x12K\n\x08revision\x18\t \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12K\n\trevisions\x18\x08 \x03(\x0b\x32\x38.CPublishedFile_FileSubscribed_Notification.RevisionData\x1a\xbb\x01\n\x0cRevisionData\x12K\n\x08revision\x18\x01 \x01(\x0e\x32\x17.EPublishedFileRevision: k_EPublishedFileRevision_Default\x12\x15\n\rfile_hcontent\x18\x02 \x01(\x06\x12\x15\n\rrtime_updated\x18\x03 \x01(\r\x12\x17\n\x0fgame_branch_min\x18\x04 \x01(\t\x12\x17\n\x0fgame_branch_max\x18\x05 \x01(\t\"Y\n,CPublishedFile_FileUnsubscribed_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"[\n.CPublishedFile_FileDeleted_Client_Notification\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r*\xd8\x02\n\x16\x45PublishedFileRevision\x12$\n k_EPublishedFileRevision_Default\x10\x00\x12#\n\x1fk_EPublishedFileRevision_Latest\x10\x01\x12-\n)k_EPublishedFileRevision_ApprovedSnapshot\x10\x02\x12\x33\n/k_EPublishedFileRevision_ApprovedSnapshot_China\x10\x03\x12-\n)k_EPublishedFileRevision_RejectedSnapshot\x10\x04\x12\x33\n/k_EPublishedFileRevision_RejectedSnapshot_China\x10\x05\x12+\n\'k_EPublishedFileRevision_AuthorSnapshot\x10\x06*\xc8\x01\n\x1b\x45PublishedFileForSaleStatus\x12\x16\n\x12k_PFFSS_NotForSale\x10\x00\x12\x1b\n\x17k_PFFSS_PendingApproval\x10\x01\x12\x1b\n\x17k_PFFSS_ApprovedForSale\x10\x02\x12\x1b\n\x17k_PFFSS_RejectedForSale\x10\x03\x12\x1b\n\x17k_PFFSS_NoLongerForSale\x10\x04\x12\x1d\n\x19k_PFFSS_TentativeApproval\x10\x05\x32\xdd\x1b\n\rPublishedFile\x12\x43\n\x04Vote\x12\x1c.CPublishedFile_Vote_Request\x1a\x1d.CPublishedFile_Vote_Response\x12R\n\tSubscribe\x12!.CPublishedFile_Subscribe_Request\x1a\".CPublishedFile_Subscribe_Response\x12X\n\x0bUnsubscribe\x12#.CPublishedFile_Unsubscribe_Request\x1a$.CPublishedFile_Unsubscribe_Response\x12[\n\x0c\x43\x61nSubscribe\x12$.CPublishedFile_CanSubscribe_Request\x1a%.CPublishedFile_CanSubscribe_Response\x12j\n\x11GetSubSectionData\x12).CPublishedFile_GetSubSectionData_Request\x1a*.CPublishedFile_GetSubSectionData_Response\x12L\n\x07Publish\x12\x1f.CPublishedFile_Publish_Request\x1a .CPublishedFile_Publish_Response\x12U\n\nGetDetails\x12\".CPublishedFile_GetDetails_Request\x1a#.CPublishedFile_GetDetails_Response\x12X\n\x0bGetItemInfo\x12#.CPublishedFile_GetItemInfo_Request\x1a$.CPublishedFile_GetItemInfo_Response\x12[\n\x0cGetUserFiles\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\x12_\n\x10GetUserFileCount\x12$.CPublishedFile_GetUserFiles_Request\x1a%.CPublishedFile_GetUserFiles_Response\x12\x85\x01\n\x1a\x41reFilesInSubscriptionList\x12\x32.CPublishedFile_AreFilesInSubscriptionList_Request\x1a\x33.CPublishedFile_AreFilesInSubscriptionList_Response\x12I\n\x06Update\x12\x1e.CPublishedFile_Update_Request\x1a\x1f.CPublishedFile_Update_Response\x12I\n\x06\x44\x65lete\x12\x1e.CPublishedFile_Delete_Request\x1a\x1f.CPublishedFile_Delete_Response\x12v\n\x15GetChangeHistoryEntry\x12-.CPublishedFile_GetChangeHistoryEntry_Request\x1a..CPublishedFile_GetChangeHistoryEntry_Response\x12g\n\x10GetChangeHistory\x12(.CPublishedFile_GetChangeHistory_Request\x1a).CPublishedFile_GetChangeHistory_Response\x12m\n\x12RefreshVotingQueue\x12*.CPublishedFile_RefreshVotingQueue_Request\x1a+.CPublishedFile_RefreshVotingQueue_Response\x12U\n\nQueryFiles\x12\".CPublishedFile_QueryFiles_Request\x1a#.CPublishedFile_QueryFiles_Response\x12m\n\x12\x41\x64\x64\x41ppRelationship\x12*.CPublishedFile_AddAppRelationship_Request\x1a+.CPublishedFile_AddAppRelationship_Response\x12v\n\x15RemoveAppRelationship\x12-.CPublishedFile_RemoveAppRelationship_Request\x1a..CPublishedFile_RemoveAppRelationship_Response\x12p\n\x13GetAppRelationships\x12+.CPublishedFile_GetAppRelationships_Request\x1a,.CPublishedFile_GetAppRelationships_Response\x12\x85\x01\n\x1aGetAppRelationshipsBatched\x12\x32.CPublishedFile_GetAppRelationshipsBatched_Request\x1a\x33.CPublishedFile_GetAppRelationshipsBatched_Response\x12v\n\x15StartPlaytimeTracking\x12-.CPublishedFile_StartPlaytimeTracking_Request\x1a..CPublishedFile_StartPlaytimeTracking_Response\x12s\n\x14StopPlaytimeTracking\x12,.CPublishedFile_StopPlaytimeTracking_Request\x1a-.CPublishedFile_StopPlaytimeTracking_Response\x12\x9d\x01\n\"StopPlaytimeTrackingForAllAppItems\x12:.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Request\x1a;.CPublishedFile_StopPlaytimeTrackingForAllAppItems_Response\x12\x94\x01\n\x1fSetPlaytimeForControllerConfigs\x12\x37.CPublishedFile_SetPlaytimeForControllerConfigs_Request\x1a\x38.CPublishedFile_SetPlaytimeForControllerConfigs_Response\x12O\n\x08\x41\x64\x64\x43hild\x12 .CPublishedFile_AddChild_Request\x1a!.CPublishedFile_AddChild_Response\x12X\n\x0bRemoveChild\x12#.CPublishedFile_RemoveChild_Request\x1a$.CPublishedFile_RemoveChild_Response\x12v\n\x15SetCollectionChildren\x12-.CPublishedFile_SetCollectionChildren_Request\x1a..CPublishedFile_SetCollectionChildren_Response\x12\x9a\x01\n!SetSubscriptionListFromCollection\x12\x39.CPublishedFile_SetSubscriptionListFromCollection_Request\x1a:.CPublishedFile_SetSubscriptionListFromCollection_Response\x12m\n\x12GetUserVoteSummary\x12*.CPublishedFile_GetUserVoteSummary_Request\x1a+.CPublishedFile_GetUserVoteSummary_Response\x12\x61\n\x0eGetItemChanges\x12&.CPublishedFile_GetItemChanges_Request\x1a\'.CPublishedFile_GetItemChanges_Response\x12v\n\x15GetContentDescriptors\x12-.CPublishedFile_GetContentDescriptors_Request\x1a..CPublishedFile_GetContentDescriptors_Response\x12\x7f\n\x18UpdateContentDescriptors\x12\x30.CPublishedFile_UpdateContentDescriptors_Request\x1a\x31.CPublishedFile_UpdateContentDescriptors_Response2\x96\x02\n\x13PublishedFileClient\x12P\n\x14NotifyFileSubscribed\x12+.CPublishedFile_FileSubscribed_Notification\x1a\x0b.NoResponse\x12T\n\x16NotifyFileUnsubscribed\x12-.CPublishedFile_FileUnsubscribed_Notification\x1a\x0b.NoResponse\x12Q\n\x11NotifyFileDeleted\x12/.CPublishedFile_FileDeleted_Client_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_publishedfile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _PUBLISHEDFILECLIENT._options = None
  _PUBLISHEDFILECLIENT._serialized_options = b'\300\265\030\002'
  _EPUBLISHEDFILEREVISION._serialized_start=15337
  _EPUBLISHEDFILEREVISION._serialized_end=15681
  _EPUBLISHEDFILEFORSALESTATUS._serialized_start=15684
  _EPUBLISHEDFILEFORSALESTATUS._serialized_end=15884
  _CPUBLISHEDFILE_VOTE_REQUEST._serialized_start=122
  _CPUBLISHEDFILE_VOTE_REQUEST._serialized_end=193
  _CPUBLISHEDFILE_VOTE_RESPONSE._serialized_start=195
  _CPUBLISHEDFILE_VOTE_RESPONSE._serialized_end=225
  _CPUBLISHEDFILE_SUBSCRIBE_REQUEST._serialized_start=228
  _CPUBLISHEDFILE_SUBSCRIBE_REQUEST._serialized_end=374
  _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE._serialized_start=376
  _CPUBLISHEDFILE_SUBSCRIBE_RESPONSE._serialized_end=411
  _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST._serialized_start=413
  _CPUBLISHEDFILE_UNSUBSCRIBE_REQUEST._serialized_end=531
  _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE._serialized_start=533
  _CPUBLISHEDFILE_UNSUBSCRIBE_RESPONSE._serialized_end=570
  _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST._serialized_start=572
  _CPUBLISHEDFILE_CANSUBSCRIBE_REQUEST._serialized_end=634
  _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE._serialized_start=636
  _CPUBLISHEDFILE_CANSUBSCRIBE_RESPONSE._serialized_end=697
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST._serialized_start=700
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_REQUEST._serialized_end=911
  _PUBLISHEDFILESUBSECTION._serialized_start=913
  _PUBLISHEDFILESUBSECTION._serialized_end=1018
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE._serialized_start=1020
  _CPUBLISHEDFILE_GETSUBSECTIONDATA_RESPONSE._serialized_end=1111
  _CPUBLISHEDFILE_PUBLISH_REQUEST._serialized_start=1114
  _CPUBLISHEDFILE_PUBLISH_REQUEST._serialized_end=1495
  _CPUBLISHEDFILE_PUBLISH_RESPONSE._serialized_start=1497
  _CPUBLISHEDFILE_PUBLISH_RESPONSE._serialized_end=1577
  _CPUBLISHEDFILE_GETDETAILS_REQUEST._serialized_start=1580
  _CPUBLISHEDFILE_GETDETAILS_REQUEST._serialized_end=2087
  _PUBLISHEDFILEAUTHORSNAPSHOT._serialized_start=2089
  _PUBLISHEDFILEAUTHORSNAPSHOT._serialized_end=2207
  _PUBLISHEDFILEDETAILS._serialized_start=2210
  _PUBLISHEDFILEDETAILS._serialized_end=5164
  _PUBLISHEDFILEDETAILS_TAG._serialized_start=4349
  _PUBLISHEDFILEDETAILS_TAG._serialized_end=4408
  _PUBLISHEDFILEDETAILS_PREVIEW._serialized_start=4411
  _PUBLISHEDFILEDETAILS_PREVIEW._serialized_end=4577
  _PUBLISHEDFILEDETAILS_CHILD._serialized_start=4579
  _PUBLISHEDFILEDETAILS_CHILD._serialized_end=4649
  _PUBLISHEDFILEDETAILS_KVTAG._serialized_start=4651
  _PUBLISHEDFILEDETAILS_KVTAG._serialized_end=4686
  _PUBLISHEDFILEDETAILS_VOTEDATA._serialized_start=4689
  _PUBLISHEDFILEDETAILS_VOTEDATA._serialized_end=4829
  _PUBLISHEDFILEDETAILS_FORSALEDATA._serialized_start=4832
  _PUBLISHEDFILEDETAILS_FORSALEDATA._serialized_end=5052
  _PUBLISHEDFILEDETAILS_PLAYTIMESTATS._serialized_start=5054
  _PUBLISHEDFILEDETAILS_PLAYTIMESTATS._serialized_end=5117
  _PUBLISHEDFILEDETAILS_REACTION._serialized_start=5119
  _PUBLISHEDFILEDETAILS_REACTION._serialized_end=5164
  _CPUBLISHEDFILE_GETDETAILS_RESPONSE._serialized_start=5166
  _CPUBLISHEDFILE_GETDETAILS_RESPONSE._serialized_end=5255
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST._serialized_start=5258
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST._serialized_end=5561
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM._serialized_start=5413
  _CPUBLISHEDFILE_GETITEMINFO_REQUEST_WORKSHOPITEM._serialized_end=5561
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE._serialized_start=5564
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE._serialized_end=5963
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO._serialized_start=5727
  _CPUBLISHEDFILE_GETITEMINFO_RESPONSE_WORKSHOPITEMINFO._serialized_end=5963
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST._serialized_start=5966
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST._serialized_end=7124
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG._serialized_start=4651
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_KVTAG._serialized_end=4686
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP._serialized_start=7100
  _CPUBLISHEDFILE_GETUSERFILES_REQUEST_TAGGROUP._serialized_end=7124
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE._serialized_start=7127
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE._serialized_end=7383
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP._serialized_start=7312
  _CPUBLISHEDFILE_GETUSERFILES_RESPONSE_APP._serialized_end=7383
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST._serialized_start=7386
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_REQUEST._serialized_end=7540
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE._serialized_start=7543
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE._serialized_end=7721
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST._serialized_start=7672
  _CPUBLISHEDFILE_AREFILESINSUBSCRIPTIONLIST_RESPONSE_INLIST._serialized_end=7721
  _CPUBLISHEDFILE_UPDATE_REQUEST._serialized_start=7724
  _CPUBLISHEDFILE_UPDATE_REQUEST._serialized_end=7996
  _CPUBLISHEDFILE_UPDATE_RESPONSE._serialized_start=7998
  _CPUBLISHEDFILE_UPDATE_RESPONSE._serialized_end=8030
  _CPUBLISHEDFILE_DELETE_REQUEST._serialized_start=8032
  _CPUBLISHEDFILE_DELETE_REQUEST._serialized_end=8103
  _CPUBLISHEDFILE_DELETE_RESPONSE._serialized_start=8105
  _CPUBLISHEDFILE_DELETE_RESPONSE._serialized_end=8137
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST._serialized_start=8139
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_REQUEST._serialized_end=8247
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE._serialized_start=8250
  _CPUBLISHEDFILE_GETCHANGEHISTORYENTRY_RESPONSE._serialized_end=8456
  _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST._serialized_start=8459
  _CPUBLISHEDFILE_GETCHANGEHISTORY_REQUEST._serialized_end=8601
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE._serialized_start=8604
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE._serialized_end=8923
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG._serialized_start=8734
  _CPUBLISHEDFILE_GETCHANGEHISTORY_RESPONSE_CHANGELOG._serialized_end=8923
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST._serialized_start=8926
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_REQUEST._serialized_end=9192
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE._serialized_start=9194
  _CPUBLISHEDFILE_REFRESHVOTINGQUEUE_RESPONSE._serialized_end=9238
  _CPUBLISHEDFILE_QUERYFILES_REQUEST._serialized_start=9241
  _CPUBLISHEDFILE_QUERYFILES_REQUEST._serialized_end=10629
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG._serialized_start=4651
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_KVTAG._serialized_end=4686
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP._serialized_start=7100
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_TAGGROUP._serialized_end=7124
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE._serialized_start=10570
  _CPUBLISHEDFILE_QUERYFILES_REQUEST_DATERANGE._serialized_end=10629
  _CPUBLISHEDFILE_QUERYFILES_RESPONSE._serialized_start=10631
  _CPUBLISHEDFILE_QUERYFILES_RESPONSE._serialized_end=10756
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST._serialized_start=10758
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_REQUEST._serialized_end=10863
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE._serialized_start=10865
  _CPUBLISHEDFILE_ADDAPPRELATIONSHIP_RESPONSE._serialized_end=10909
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST._serialized_start=10911
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_REQUEST._serialized_end=11019
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE._serialized_start=11021
  _CPUBLISHEDFILE_REMOVEAPPRELATIONSHIP_RESPONSE._serialized_end=11068
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST._serialized_start=11070
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_REQUEST._serialized_end=11139
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE._serialized_start=11142
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP._serialized_start=11278
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPS_RESPONSE_APPRELATIONSHIP._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_REQUEST._serialized_start=11334
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_REQUEST._serialized_end=11440
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE._serialized_start=11443
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE._serialized_end=11826
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_APPRELATIONSHIP._serialized_start=11278
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_APPRELATIONSHIP._serialized_end=11332
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_PUBLISHEDFILEAPPRELATIONSHIP._serialized_start=11659
  _CPUBLISHEDFILE_GETAPPRELATIONSHIPSBATCHED_RESPONSE_PUBLISHEDFILEAPPRELATIONSHIP._serialized_end=11826
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST._serialized_start=11828
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_REQUEST._serialized_end=11915
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE._serialized_start=11917
  _CPUBLISHEDFILE_STARTPLAYTIMETRACKING_RESPONSE._serialized_end=11964
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST._serialized_start=11966
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_REQUEST._serialized_end=12052
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE._serialized_start=12054
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKING_RESPONSE._serialized_end=12100
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST._serialized_start=12102
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_REQUEST._serialized_end=12176
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE._serialized_start=12178
  _CPUBLISHEDFILE_STOPPLAYTIMETRACKINGFORALLAPPITEMS_RESPONSE._serialized_end=12238
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST._serialized_start=12241
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST._serialized_end=12498
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE._serialized_start=12426
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_REQUEST_CONTROLLERCONFIGUSAGE._serialized_end=12498
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE._serialized_start=12500
  _CPUBLISHEDFILE_SETPLAYTIMEFORCONTROLLERCONFIGS_RESPONSE._serialized_end=12557
  _CPUBLISHEDFILE_ADDCHILD_REQUEST._serialized_start=12559
  _CPUBLISHEDFILE_ADDCHILD_REQUEST._serialized_end=12648
  _CPUBLISHEDFILE_ADDCHILD_RESPONSE._serialized_start=12650
  _CPUBLISHEDFILE_ADDCHILD_RESPONSE._serialized_end=12684
  _CPUBLISHEDFILE_REMOVECHILD_REQUEST._serialized_start=12686
  _CPUBLISHEDFILE_REMOVECHILD_REQUEST._serialized_end=12778
  _CPUBLISHEDFILE_REMOVECHILD_RESPONSE._serialized_start=12780
  _CPUBLISHEDFILE_REMOVECHILD_RESPONSE._serialized_end=12817
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_REQUEST._serialized_start=12819
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_REQUEST._serialized_end=12923
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_RESPONSE._serialized_start=12925
  _CPUBLISHEDFILE_SETCOLLECTIONCHILDREN_RESPONSE._serialized_end=12972
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_REQUEST._serialized_start=12975
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_REQUEST._serialized_end=13110
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_RESPONSE._serialized_start=13112
  _CPUBLISHEDFILE_SETSUBSCRIPTIONLISTFROMCOLLECTION_RESPONSE._serialized_end=13171
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST._serialized_start=13173
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_REQUEST._serialized_end=13242
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE._serialized_start=13245
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE._serialized_end=13463
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY._serialized_start=13367
  _CPUBLISHEDFILE_GETUSERVOTESUMMARY_RESPONSE_VOTESUMMARY._serialized_end=13463
  _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST._serialized_start=13466
  _CPUBLISHEDFILE_GETITEMCHANGES_REQUEST._serialized_end=13655
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE._serialized_start=13658
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE._serialized_end=13948
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO._serialized_start=13804
  _CPUBLISHEDFILE_GETITEMCHANGES_RESPONSE_WORKSHOPITEMINFO._serialized_end=13948
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_REQUEST._serialized_start=13950
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_REQUEST._serialized_end=14021
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE._serialized_start=14024
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE._serialized_end=14338
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE_CONTENTDESCRIPTOR._serialized_start=14169
  _CPUBLISHEDFILE_GETCONTENTDESCRIPTORS_RESPONSE_CONTENTDESCRIPTOR._serialized_end=14338
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_REQUEST._serialized_start=14341
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_REQUEST._serialized_end=14520
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_RESPONSE._serialized_start=14522
  _CPUBLISHEDFILE_UPDATECONTENTDESCRIPTORS_RESPONSE._serialized_end=14599
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION._serialized_start=14602
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION._serialized_end=15150
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA._serialized_start=14963
  _CPUBLISHEDFILE_FILESUBSCRIBED_NOTIFICATION_REVISIONDATA._serialized_end=15150
  _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION._serialized_start=15152
  _CPUBLISHEDFILE_FILEUNSUBSCRIBED_NOTIFICATION._serialized_end=15241
  _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION._serialized_start=15243
  _CPUBLISHEDFILE_FILEDELETED_CLIENT_NOTIFICATION._serialized_end=15334
  _PUBLISHEDFILE._serialized_start=15887
  _PUBLISHEDFILE._serialized_end=19436
  _PUBLISHEDFILECLIENT._serialized_start=19439
  _PUBLISHEDFILECLIENT._serialized_end=19717
_builder.BuildServices(DESCRIPTOR, 'steammessages_publishedfile_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_unified_test.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"5\n CMsgTest_MessageToClient_Request\x12\x11\n\tsome_text\x18\x01 \x01(\t\"6\n!CMsgTest_MessageToClient_Response\x12\x11\n\tsome_text\x18\x01 \x01(\t\"7\n\"CMsgTest_NotifyClient_Notification\x12\x11\n\tsome_text\x18\x01 \x01(\t\"5\n CMsgTest_MessageToServer_Request\x12\x11\n\tsome_text\x18\x01 \x01(\t\"6\n!CMsgTest_MessageToServer_Response\x12\x11\n\tsome_text\x18\x01 \x01(\t\"7\n\"CMsgTest_NotifyServer_Notification\x12\x11\n\tsome_text\x18\x01 \x01(\t\"0\n\x1f\x43MsgTest_TestClientCall_Request\x12\r\n\x05param\x18\x01 \x01(\x05\"2\n CMsgTest_TestClientCall_Response\x12\x0e\n\x06result\x18\x01 \x01(\x05\"\x19\n\x17\x43MsgTest_NoBody_Request\"1\n\x1c\x43MsgTest_CallClient_Response\x12\x11\n\ttestvalue\x18\x01 \x01(\x05\x32\xb3\x01\n\x0fTestSteamClient\x12X\n\x0fMessageToClient\x12!.CMsgTest_MessageToClient_Request\x1a\".CMsgTest_MessageToClient_Response\x12@\n\x0cNotifyClient\x12#.CMsgTest_NotifyClient_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x32\x9a\x04\n\x14TestServerFromClient\x12X\n\x0fMessageToServer\x12!.CMsgTest_MessageToServer_Request\x1a\".CMsgTest_MessageToServer_Response\x12@\n\x0cNotifyServer\x12#.CMsgTest_NotifyServer_Notification\x1a\x0b.NoResponse\x12X\n\x11\x43lientCallAuthed1\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed2\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed3\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response\x12X\n\x11\x43lientCallAuthed4\x12 .CMsgTest_TestClientCall_Request\x1a!.CMsgTest_TestClientCall_Response2^\n\x15TestExternalPrivilege\x12\x45\n\nCallClient\x12\x18.CMsgTest_NoBody_Request\x1a\x1d.CMsgTest_CallClient_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_unified_test_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _TESTSTEAMCLIENT._options = None
  _TESTSTEAMCLIENT._serialized_options = b'\300\265\030\002'
  _CMSGTEST_MESSAGETOCLIENT_REQUEST._serialized_start=96
  _CMSGTEST_MESSAGETOCLIENT_REQUEST._serialized_end=149
  _CMSGTEST_MESSAGETOCLIENT_RESPONSE._serialized_start=151
  _CMSGTEST_MESSAGETOCLIENT_RESPONSE._serialized_end=205
  _CMSGTEST_NOTIFYCLIENT_NOTIFICATION._serialized_start=207
  _CMSGTEST_NOTIFYCLIENT_NOTIFICATION._serialized_end=262
  _CMSGTEST_MESSAGETOSERVER_REQUEST._serialized_start=264
  _CMSGTEST_MESSAGETOSERVER_REQUEST._serialized_end=317
  _CMSGTEST_MESSAGETOSERVER_RESPONSE._serialized_start=319
  _CMSGTEST_MESSAGETOSERVER_RESPONSE._serialized_end=373
  _CMSGTEST_NOTIFYSERVER_NOTIFICATION._serialized_start=375
  _CMSGTEST_NOTIFYSERVER_NOTIFICATION._serialized_end=430
  _CMSGTEST_TESTCLIENTCALL_REQUEST._serialized_start=432
  _CMSGTEST_TESTCLIENTCALL_REQUEST._serialized_end=480
  _CMSGTEST_TESTCLIENTCALL_RESPONSE._serialized_start=482
  _CMSGTEST_TESTCLIENTCALL_RESPONSE._serialized_end=532
  _CMSGTEST_NOBODY_REQUEST._serialized_start=534
  _CMSGTEST_NOBODY_REQUEST._serialized_end=559
  _CMSGTEST_CALLCLIENT_RESPONSE._serialized_start=561
  _CMSGTEST_CALLCLIENT_RESPONSE._serialized_end=610
  _TESTSTEAMCLIENT._serialized_start=613
  _TESTSTEAMCLIENT._serialized_end=792
  _TESTSERVERFROMCLIENT._serialized_start=795
  _TESTSERVERFROMCLIENT._serialized_end=1333
  _TESTEXTERNALPRIVILEGE._serialized_start=1335
  _TESTEXTERNALPRIVILEGE._serialized_end=1429
_builder.BuildServices(DESCRIPTOR, 'steammessages_unified_test_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_friends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(steammessages_clientserver_friends.proto\x1a\x18steammessages_base.proto\"\x8a\x01\n\x13\x43MsgClientFriendMsg\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\x0c\x12 \n\x18rtime32_server_timestamp\x18\x04 \x01(\x07\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x05 \x01(\x08\"\x9d\x01\n\x1b\x43MsgClientFriendMsgIncoming\x12\x14\n\x0csteamid_from\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x1c\n\x14\x66rom_limited_account\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\x0c\x12 \n\x18rtime32_server_timestamp\x18\x05 \x01(\x07\"R\n\x13\x43MsgClientAddFriend\x12\x16\n\x0esteamid_to_add\x18\x01 \x01(\x06\x12#\n\x1b\x61\x63\x63ountname_or_email_to_add\x18\x02 \x01(\t\"e\n\x1b\x43MsgClientAddFriendResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0esteam_id_added\x18\x02 \x01(\x06\x12\x1a\n\x12persona_name_added\x18\x03 \x01(\t\"*\n\x16\x43MsgClientRemoveFriend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\"6\n\x14\x43MsgClientHideFriend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\x12\x0c\n\x04hide\x18\x02 \x01(\x08\"\xea\x01\n\x15\x43MsgClientFriendsList\x12\x14\n\x0c\x62incremental\x18\x01 \x01(\x08\x12.\n\x07\x66riends\x18\x02 \x03(\x0b\x32\x1d.CMsgClientFriendsList.Friend\x12\x18\n\x10max_friend_count\x18\x03 \x01(\r\x12\x1b\n\x13\x61\x63tive_friend_count\x18\x04 \x01(\r\x12\x19\n\x11\x66riends_limit_hit\x18\x05 \x01(\x08\x1a\x39\n\x06\x46riend\x12\x12\n\nulfriendid\x18\x01 \x01(\x06\x12\x1b\n\x13\x65\x66riendrelationship\x18\x02 \x01(\r\"\xc5\x02\n\x1b\x43MsgClientFriendsGroupsList\x12\x10\n\x08\x62removal\x18\x01 \x01(\x08\x12\x14\n\x0c\x62incremental\x18\x02 \x01(\x08\x12>\n\x0c\x66riendGroups\x18\x03 \x03(\x0b\x32(.CMsgClientFriendsGroupsList.FriendGroup\x12H\n\x0bmemberships\x18\x04 \x03(\x0b\x32\x33.CMsgClientFriendsGroupsList.FriendGroupsMembership\x1a\x35\n\x0b\x46riendGroup\x12\x10\n\x08nGroupID\x18\x01 \x01(\x05\x12\x14\n\x0cstrGroupName\x18\x02 \x01(\t\x1a=\n\x16\x46riendGroupsMembership\x12\x11\n\tulSteamID\x18\x01 \x01(\x06\x12\x10\n\x08nGroupID\x18\x02 \x01(\x05\"\xba\x01\n\x1c\x43MsgClientPlayerNicknameList\x12\x0f\n\x07removal\x18\x01 \x01(\x08\x12\x13\n\x0bincremental\x18\x02 \x01(\x08\x12?\n\tnicknames\x18\x03 \x03(\x0b\x32,.CMsgClientPlayerNicknameList.PlayerNickname\x1a\x33\n\x0ePlayerNickname\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08nickname\x18\x03 \x01(\t\"@\n\x1b\x43MsgClientSetPlayerNickname\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08nickname\x18\x02 \x01(\t\"6\n#CMsgClientSetPlayerNicknameResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"O\n\x1b\x43MsgClientRequestFriendData\x12\x1f\n\x17persona_state_requested\x18\x01 \x01(\r\x12\x0f\n\x07\x66riends\x18\x02 \x03(\x06\"\xef\x01\n\x16\x43MsgClientChangeStatus\x12\x15\n\rpersona_state\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\x12\x1e\n\x16is_auto_generated_name\x18\x03 \x01(\x08\x12\x15\n\rhigh_priority\x18\x04 \x01(\x08\x12\x1b\n\x13persona_set_by_user\x18\x05 \x01(\x08\x12\x1e\n\x13persona_state_flags\x18\x06 \x01(\r:\x01\x30\x12\x1d\n\x15need_persona_response\x18\x07 \x01(\x08\x12\x16\n\x0eis_client_idle\x18\x08 \x01(\x08\"@\n\x19\x43MsgPersonaChangeResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\"\xd9\t\n\x16\x43MsgClientPersonaState\x12\x14\n\x0cstatus_flags\x18\x01 \x01(\r\x12/\n\x07\x66riends\x18\x02 \x03(\x0b\x32\x1e.CMsgClientPersonaState.Friend\x1a\xf7\x08\n\x06\x46riend\x12\x10\n\x08\x66riendid\x18\x01 \x01(\x06\x12\x15\n\rpersona_state\x18\x02 \x01(\r\x12\x1a\n\x12game_played_app_id\x18\x03 \x01(\r\x12\x16\n\x0egame_server_ip\x18\x04 \x01(\r\x12\x18\n\x10game_server_port\x18\x05 \x01(\r\x12\x1b\n\x13persona_state_flags\x18\x06 \x01(\r\x12 \n\x18online_session_instances\x18\x07 \x01(\r\x12\x1b\n\x13persona_set_by_user\x18\n \x01(\x08\x12\x13\n\x0bplayer_name\x18\x0f \x01(\t\x12\x12\n\nquery_port\x18\x14 \x01(\r\x12\x16\n\x0esteamid_source\x18\x19 \x01(\x06\x12\x13\n\x0b\x61vatar_hash\x18\x1f \x01(\x0c\x12\x13\n\x0blast_logoff\x18- \x01(\r\x12\x12\n\nlast_logon\x18. \x01(\r\x12\x18\n\x10last_seen_online\x18/ \x01(\r\x12\x11\n\tclan_rank\x18\x32 \x01(\r\x12\x11\n\tgame_name\x18\x37 \x01(\t\x12\x0e\n\x06gameid\x18\x38 \x01(\x06\x12\x16\n\x0egame_data_blob\x18< \x01(\x0c\x12:\n\tclan_data\x18@ \x01(\x0b\x32\'.CMsgClientPersonaState.Friend.ClanData\x12\x10\n\x08\x63lan_tag\x18\x41 \x01(\t\x12\x38\n\rrich_presence\x18G \x03(\x0b\x32!.CMsgClientPersonaState.Friend.KV\x12\x14\n\x0c\x62roadcast_id\x18H \x01(\x06\x12\x15\n\rgame_lobby_id\x18I \x01(\x06\x12$\n\x1cwatching_broadcast_accountid\x18J \x01(\r\x12 \n\x18watching_broadcast_appid\x18K \x01(\r\x12\"\n\x1awatching_broadcast_viewers\x18L \x01(\r\x12 \n\x18watching_broadcast_title\x18M \x01(\t\x12\x1b\n\x13is_community_banned\x18N \x01(\x08\x12\"\n\x1aplayer_name_pending_review\x18O \x01(\x08\x12\x1d\n\x15\x61vatar_pending_review\x18P \x01(\x08\x12\x15\n\ron_steam_deck\x18Q \x01(\x08\x12\x45\n\x0fother_game_data\x18R \x03(\x0b\x32,.CMsgClientPersonaState.Friend.OtherGameData\x1a\x35\n\x08\x43lanData\x12\x12\n\nogg_app_id\x18\x01 \x01(\r\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\x1a \n\x02KV\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1aY\n\rOtherGameData\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\x38\n\rrich_presence\x18\x02 \x03(\x0b\x32!.CMsgClientPersonaState.Friend.KV\"5\n\x1b\x43MsgClientFriendProfileInfo\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\"\xda\x01\n#CMsgClientFriendProfileInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0esteamid_friend\x18\x02 \x01(\x06\x12\x14\n\x0ctime_created\x18\x03 \x01(\r\x12\x11\n\treal_name\x18\x04 \x01(\t\x12\x11\n\tcity_name\x18\x05 \x01(\t\x12\x12\n\nstate_name\x18\x06 \x01(\t\x12\x14\n\x0c\x63ountry_name\x18\x07 \x01(\t\x12\x10\n\x08headline\x18\x08 \x01(\t\x12\x0f\n\x07summary\x18\t \x01(\t\"[\n\x1c\x43MsgClientCreateFriendsGroup\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tgroupname\x18\x02 \x01(\t\x12\x17\n\x0fsteamid_friends\x18\x03 \x03(\x06\"H\n$CMsgClientCreateFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\x12\x0f\n\x07groupid\x18\x02 \x01(\x05\"@\n\x1c\x43MsgClientDeleteFriendsGroup\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07groupid\x18\x02 \x01(\x05\"7\n$CMsgClientDeleteFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"\x82\x01\n\x1c\x43MsgClientManageFriendsGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x11\n\tgroupname\x18\x02 \x01(\t\x12\x1d\n\x15steamid_friends_added\x18\x03 \x03(\x06\x12\x1f\n\x17steamid_friends_removed\x18\x04 \x03(\x06\"7\n$CMsgClientManageFriendsGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"B\n\x1a\x43MsgClientAddFriendToGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x13\n\x0bsteamiduser\x18\x02 \x01(\x06\"5\n\"CMsgClientAddFriendToGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"G\n\x1f\x43MsgClientRemoveFriendFromGroup\x12\x0f\n\x07groupid\x18\x01 \x01(\x05\x12\x13\n\x0bsteamiduser\x18\x02 \x01(\x06\":\n\'CMsgClientRemoveFriendFromGroupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"\x1b\n\x19\x43MsgClientGetEmoticonList\"\x87\x04\n\x16\x43MsgClientEmoticonList\x12\x33\n\temoticons\x18\x01 \x03(\x0b\x32 .CMsgClientEmoticonList.Emoticon\x12\x31\n\x08stickers\x18\x02 \x03(\x0b\x32\x1f.CMsgClientEmoticonList.Sticker\x12/\n\x07\x65\x66\x66\x65\x63ts\x18\x03 \x03(\x0b\x32\x1e.CMsgClientEmoticonList.Effect\x1ax\n\x08\x45moticon\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x16\n\x0etime_last_used\x18\x03 \x01(\r\x12\x11\n\tuse_count\x18\x04 \x01(\r\x12\x15\n\rtime_received\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\x1aw\n\x07Sticker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x15\n\rtime_received\x18\x03 \x01(\r\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x16\n\x0etime_last_used\x18\x05 \x01(\r\x12\x11\n\tuse_count\x18\x06 \x01(\r\x1a\x61\n\x06\x45\x66\x66\x65\x63t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x15\n\rtime_received\x18\x03 \x01(\r\x12\x14\n\x0cinfinite_use\x18\x04 \x01(\x08\x12\r\n\x05\x61ppid\x18\x05 \x01(\rB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_friends_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTFRIENDMSG._serialized_start=71
  _CMSGCLIENTFRIENDMSG._serialized_end=209
  _CMSGCLIENTFRIENDMSGINCOMING._serialized_start=212
  _CMSGCLIENTFRIENDMSGINCOMING._serialized_end=369
  _CMSGCLIENTADDFRIEND._serialized_start=371
  _CMSGCLIENTADDFRIEND._serialized_end=453
  _CMSGCLIENTADDFRIENDRESPONSE._serialized_start=455
  _CMSGCLIENTADDFRIENDRESPONSE._serialized_end=556
  _CMSGCLIENTREMOVEFRIEND._serialized_start=558
  _CMSGCLIENTREMOVEFRIEND._serialized_end=600
  _CMSGCLIENTHIDEFRIEND._serialized_start=602
  _CMSGCLIENTHIDEFRIEND._serialized_end=656
  _CMSGCLIENTFRIENDSLIST._serialized_start=659
  _CMSGCLIENTFRIENDSLIST._serialized_end=893
  _CMSGCLIENTFRIENDSLIST_FRIEND._serialized_start=836
  _CMSGCLIENTFRIENDSLIST_FRIEND._serialized_end=893
  _CMSGCLIENTFRIENDSGROUPSLIST._serialized_start=896
  _CMSGCLIENTFRIENDSGROUPSLIST._serialized_end=1221
  _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP._serialized_start=1105
  _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUP._serialized_end=1158
  _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP._serialized_start=1160
  _CMSGCLIENTFRIENDSGROUPSLIST_FRIENDGROUPSMEMBERSHIP._serialized_end=1221
  _CMSGCLIENTPLAYERNICKNAMELIST._serialized_start=1224
  _CMSGCLIENTPLAYERNICKNAMELIST._serialized_end=1410
  _CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME._serialized_start=1359
  _CMSGCLIENTPLAYERNICKNAMELIST_PLAYERNICKNAME._serialized_end=1410
  _CMSGCLIENTSETPLAYERNICKNAME._serialized_start=1412
  _CMSGCLIENTSETPLAYERNICKNAME._serialized_end=1476
  _CMSGCLIENTSETPLAYERNICKNAMERESPONSE._serialized_start=1478
  _CMSGCLIENTSETPLAYERNICKNAMERESPONSE._serialized_end=1532
  _CMSGCLIENTREQUESTFRIENDDATA._serialized_start=1534
  _CMSGCLIENTREQUESTFRIENDDATA._serialized_end=1613
  _CMSGCLIENTCHANGESTATUS._serialized_start=1616
  _CMSGCLIENTCHANGESTATUS._serialized_end=1855
  _CMSGPERSONACHANGERESPONSE._serialized_start=1857
  _CMSGPERSONACHANGERESPONSE._serialized_end=1921
  _CMSGCLIENTPERSONASTATE._serialized_start=1924
  _CMSGCLIENTPERSONASTATE._serialized_end=3165
  _CMSGCLIENTPERSONASTATE_FRIEND._serialized_start=2022
  _CMSGCLIENTPERSONASTATE_FRIEND._serialized_end=3165
  _CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA._serialized_start=2987
  _CMSGCLIENTPERSONASTATE_FRIEND_CLANDATA._serialized_end=3040
  _CMSGCLIENTPERSONASTATE_FRIEND_KV._serialized_start=3042
  _CMSGCLIENTPERSONASTATE_FRIEND_KV._serialized_end=3074
  _CMSGCLIENTPERSONASTATE_FRIEND_OTHERGAMEDATA._serialized_start=3076
  _CMSGCLIENTPERSONASTATE_FRIEND_OTHERGAMEDATA._serialized_end=3165
  _CMSGCLIENTFRIENDPROFILEINFO._serialized_start=3167
  _CMSGCLIENTFRIENDPROFILEINFO._serialized_end=3220
  _CMSGCLIENTFRIENDPROFILEINFORESPONSE._serialized_start=3223
  _CMSGCLIENTFRIENDPROFILEINFORESPONSE._serialized_end=3441
  _CMSGCLIENTCREATEFRIENDSGROUP._serialized_start=3443
  _CMSGCLIENTCREATEFRIENDSGROUP._serialized_end=3534
  _CMSGCLIENTCREATEFRIENDSGROUPRESPONSE._serialized_start=3536
  _CMSGCLIENTCREATEFRIENDSGROUPRESPONSE._serialized_end=3608
  _CMSGCLIENTDELETEFRIENDSGROUP._serialized_start=3610
  _CMSGCLIENTDELETEFRIENDSGROUP._serialized_end=3674
  _CMSGCLIENTDELETEFRIENDSGROUPRESPONSE._serialized_start=3676
  _CMSGCLIENTDELETEFRIENDSGROUPRESPONSE._serialized_end=3731
  _CMSGCLIENTMANAGEFRIENDSGROUP._serialized_start=3734
  _CMSGCLIENTMANAGEFRIENDSGROUP._serialized_end=3864
  _CMSGCLIENTMANAGEFRIENDSGROUPRESPONSE._serialized_start=3866
  _CMSGCLIENTMANAGEFRIENDSGROUPRESPONSE._serialized_end=3921
  _CMSGCLIENTADDFRIENDTOGROUP._serialized_start=3923
  _CMSGCLIENTADDFRIENDTOGROUP._serialized_end=3989
  _CMSGCLIENTADDFRIENDTOGROUPRESPONSE._serialized_start=3991
  _CMSGCLIENTADDFRIENDTOGROUPRESPONSE._serialized_end=4044
  _CMSGCLIENTREMOVEFRIENDFROMGROUP._serialized_start=4046
  _CMSGCLIENTREMOVEFRIENDFROMGROUP._serialized_end=4117
  _CMSGCLIENTREMOVEFRIENDFROMGROUPRESPONSE._serialized_start=4119
  _CMSGCLIENTREMOVEFRIENDFROMGROUPRESPONSE._serialized_end=4177
  _CMSGCLIENTGETEMOTICONLIST._serialized_start=4179
  _CMSGCLIENTGETEMOTICONLIST._serialized_end=4206
  _CMSGCLIENTEMOTICONLIST._serialized_start=4209
  _CMSGCLIENTEMOTICONLIST._serialized_end=4728
  _CMSGCLIENTEMOTICONLIST_EMOTICON._serialized_start=4388
  _CMSGCLIENTEMOTICONLIST_EMOTICON._serialized_end=4508
  _CMSGCLIENTEMOTICONLIST_STICKER._serialized_start=4510
  _CMSGCLIENTEMOTICONLIST_STICKER._serialized_end=4629
  _CMSGCLIENTEMOTICONLIST_EFFECT._serialized_start=4631
  _CMSGCLIENTEMOTICONLIST_EFFECT._serialized_end=4728
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_store.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.contenthubs_pb2 as contenthubs__pb2
import steam.protobufs.steammessages_storebrowse_pb2 as steammessages__storebrowse__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19steammessages_store.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x11\x63ontenthubs.proto\x1a\x1fsteammessages_storebrowse.proto\x1a\x0b\x65nums.proto\"r\n\x1c\x43Store_RegisterCDKey_Request\x12\x17\n\x0f\x61\x63tivation_code\x18\x01 \x01(\t\x12\x19\n\x11purchase_platform\x18\x02 \x01(\x05\x12\x1e\n\x16is_request_from_client\x18\x03 \x01(\x08\"\x9b\x04\n\x1a\x43Store_PurchaseReceiptInfo\x12\x15\n\rtransactionid\x18\x01 \x01(\x04\x12\x11\n\tpackageid\x18\x02 \x01(\r\x12\x17\n\x0fpurchase_status\x18\x03 \x01(\r\x12\x15\n\rresult_detail\x18\x04 \x01(\r\x12\x18\n\x10transaction_time\x18\x05 \x01(\r\x12\x16\n\x0epayment_method\x18\x06 \x01(\r\x12\x12\n\nbase_price\x18\x07 \x01(\x04\x12\x16\n\x0etotal_discount\x18\x08 \x01(\x04\x12\x0b\n\x03tax\x18\t \x01(\x04\x12\x10\n\x08shipping\x18\n \x01(\x04\x12\x15\n\rcurrency_code\x18\x0b \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x0c \x01(\t\x12\x16\n\x0e\x65rror_headline\x18\r \x01(\t\x12\x14\n\x0c\x65rror_string\x18\x0e \x01(\t\x12\x17\n\x0f\x65rror_link_text\x18\x0f \x01(\t\x12\x16\n\x0e\x65rror_link_url\x18\x10 \x01(\t\x12\x13\n\x0b\x65rror_appid\x18\x11 \x01(\r\x12\x38\n\nline_items\x18\x12 \x03(\x0b\x32$.CStore_PurchaseReceiptInfo.LineItem\x1aK\n\x08LineItem\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x1d\n\x15line_item_description\x18\x03 \x01(\t\"|\n\x1d\x43Store_RegisterCDKey_Response\x12\x1f\n\x17purchase_result_details\x18\x01 \x01(\x05\x12:\n\x15purchase_receipt_info\x18\x02 \x01(\x0b\x32\x1b.CStore_PurchaseReceiptInfo\"l\n(CStore_GetRecommendedTagsForUser_Request\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x18\n\x10\x66\x61vor_rarer_tags\x18\x04 \x01(\x08\"\x9d\x01\n)CStore_GetRecommendedTagsForUser_Response\x12<\n\x04tags\x18\x01 \x03(\x0b\x32..CStore_GetRecommendedTagsForUser_Response.Tag\x1a\x32\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x02\"5\n!CStore_GetMostPopularTags_Request\x12\x10\n\x08language\x18\x01 \x01(\t\"\x7f\n\"CStore_GetMostPopularTags_Response\x12\x35\n\x04tags\x18\x01 \x03(\x0b\x32\'.CStore_GetMostPopularTags_Response.Tag\x1a\"\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"J\n&CStore_GetLocalizedNameForTags_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0e\n\x06tagids\x18\x02 \x03(\r\"\xb8\x01\n\'CStore_GetLocalizedNameForTags_Response\x12:\n\x04tags\x18\x01 \x03(\x0b\x32,.CStore_GetLocalizedNameForTags_Response.Tag\x1aQ\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x14\n\x0c\x65nglish_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0fnormalized_name\x18\x04 \x01(\t\"H\n\x19\x43Store_GetTagList_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x19\n\x11have_version_hash\x18\x02 \x01(\t\"\x85\x01\n\x1a\x43Store_GetTagList_Response\x12\x14\n\x0cversion_hash\x18\x01 \x01(\t\x12-\n\x04tags\x18\x02 \x03(\x0b\x32\x1f.CStore_GetTagList_Response.Tag\x1a\"\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe3\x02\n\x1c\x43StoreDiscoveryQueueSettings\x12\x0e\n\x06os_win\x18\x04 \x01(\x08\x12\x0e\n\x06os_mac\x18\x05 \x01(\x08\x12\x10\n\x08os_linux\x18\x06 \x01(\x08\x12\x1f\n\x17\x66ull_controller_support\x18\x07 \x01(\x08\x12\x1f\n\x17native_steam_controller\x18\x08 \x01(\x08\x12\x1b\n\x13include_coming_soon\x18\t \x01(\x08\x12\x17\n\x0f\x65xcluded_tagids\x18\n \x03(\r\x12\x1c\n\x14\x65xclude_early_access\x18\x0b \x01(\x08\x12\x16\n\x0e\x65xclude_videos\x18\x0c \x01(\x08\x12\x18\n\x10\x65xclude_software\x18\r \x01(\x08\x12\x13\n\x0b\x65xclude_dlc\x18\x0e \x01(\x08\x12\x1b\n\x13\x65xclude_soundtracks\x18\x0f \x01(\x08\x12\x17\n\x0f\x66\x65\x61tured_tagids\x18\x10 \x03(\r\"\x8c\x04\n CStore_GetDiscoveryQueue_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x15\n\rrebuild_queue\x18\x03 \x01(\x08\x12\x18\n\x10settings_changed\x18\x04 \x01(\x08\x12/\n\x08settings\x18\x05 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\x12\x1e\n\x16rebuild_queue_if_stale\x18\x06 \x01(\x08\x12\x1f\n\x17ignore_user_preferences\x18\x08 \x01(\x08\x12\x1f\n\x17no_experimental_results\x18\t \x01(\x08\x12\x1b\n\x13\x65xperimental_cohort\x18\n \x01(\r\x12\x1c\n\x14\x64\x65\x62ug_get_solr_query\x18\x0b \x01(\x08\x12,\n\x11store_page_filter\x18\x0c \x01(\x0b\x32\x11.CStorePageFilter\x12$\n\x07\x63ontext\x18\r \x01(\x0b\x32\x13.StoreBrowseContext\x12\x31\n\x0c\x64\x61ta_request\x18\x0e \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\"\xf6\x01\n!CStore_GetDiscoveryQueue_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12/\n\x08settings\x18\x03 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\x12\x0f\n\x07skipped\x18\x04 \x01(\x05\x12\x11\n\texhausted\x18\x05 \x01(\x08\x12\x1b\n\x13\x65xperimental_cohort\x18\x06 \x01(\r\x12\x18\n\x10\x64\x65\x62ug_solr_query\x18\x07 \x01(\t\x12\x1f\n\x0bstore_items\x18\x08 \x03(\x0b\x32\n.StoreItem\"\xa6\x01\n(CStore_GetDiscoveryQueueSettings_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12,\n\x11store_page_filter\x18\x02 \x01(\x0b\x32\x11.CStorePageFilter\"r\n)CStore_GetDiscoveryQueueSettings_Response\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12/\n\x08settings\x18\x02 \x01(\x0b\x32\x1d.CStoreDiscoveryQueueSettings\"\xb2\x01\n%CStore_SkipDiscoveryQueueItem_Request\x12L\n\nqueue_type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12,\n\x11store_page_filter\x18\x03 \x01(\x0b\x32\x11.CStorePageFilter\"(\n&CStore_SkipDiscoveryQueueItem_Response\"a\n\'CStore_GetUserGameInterestState_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0bstore_appid\x18\x02 \x01(\r\x12\x12\n\nbeta_appid\x18\x03 \x01(\r\"\xf2\x04\n(CStore_GetUserGameInterestState_Response\x12\r\n\x05owned\x18\x01 \x01(\x08\x12\x10\n\x08wishlist\x18\x02 \x01(\x08\x12\x0f\n\x07ignored\x18\x03 \x01(\x08\x12\x11\n\tfollowing\x18\x04 \x01(\x08\x12,\n\tin_queues\x18\x05 \x03(\x0e\x32\x19.EStoreDiscoveryQueueType\x12\x33\n\x10queues_with_skip\x18\x06 \x03(\x0e\x32\x19.EStoreDiscoveryQueueType\x12\x1d\n\x15queue_items_remaining\x18\x07 \x03(\x05\x12\x1e\n\x16queue_items_next_appid\x18\x08 \x03(\r\x12\x19\n\x11temporarily_owned\x18\t \x01(\x08\x12\x41\n\x06queues\x18\n \x03(\x0b\x32\x31.CStore_GetUserGameInterestState_Response.InQueue\x12\x16\n\x0eignored_reason\x18\x0b \x01(\x05\x12:\n\x0b\x62\x65ta_status\x18\x0c \x01(\x0e\x32\x10.EPlaytestStatus:\x13k_ETesterStatusNone\x1a\xac\x01\n\x07InQueue\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12\x0f\n\x07skipped\x18\x02 \x01(\x08\x12\x17\n\x0fitems_remaining\x18\x03 \x01(\x05\x12\x12\n\nnext_appid\x18\x04 \x01(\r\x12\x1b\n\x13\x65xperimental_cohort\x18\x05 \x01(\r\"\xba\x01\n+CStore_GetDiscoveryQueueSkippedApps_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12L\n\nqueue_type\x18\x02 \x01(\x0e\x32\x19.EStoreDiscoveryQueueType:\x1dk_EStoreDiscoveryQueueTypeNew\x12,\n\x11store_page_filter\x18\x03 \x01(\x0b\x32\x11.CStorePageFilter\">\n,CStore_GetDiscoveryQueueSkippedApps_Response\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\"y\n\x18\x43Store_ReportApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12>\n\x0breport_type\x18\x02 \x01(\x0e\x32\x0f.EAppReportType:\x18k_EAppReportType_Invalid\x12\x0e\n\x06report\x18\x03 \x01(\t\"\x1b\n\x19\x43Store_ReportApp_Response\"$\n\"CStore_GetStorePreferences_Request\"\xf2\x03\n\x16\x43Store_UserPreferences\x12\x18\n\x10primary_language\x18\x01 \x01(\x05\x12\x1b\n\x13secondary_languages\x18\x02 \x01(\r\x12\x18\n\x10platform_windows\x18\x03 \x01(\x08\x12\x14\n\x0cplatform_mac\x18\x04 \x01(\x08\x12\x16\n\x0eplatform_linux\x18\x05 \x01(\x08\x12\x19\n\x11timestamp_updated\x18\x08 \x01(\r\x12\x1c\n\x14hide_store_broadcast\x18\t \x01(\x08\x12`\n\x17review_score_preference\x18\n \x01(\x0e\x32\x1b.EUserReviewScorePreference:\"k_EUserReviewScorePreference_Unset\x12\x38\n0timestamp_content_descriptor_preferences_updated\x18\x0b \x01(\x05\x12\x66\n\x15provide_deck_feedback\x18\x0c \x01(\x0e\x32\x1f.EProvideDeckFeedbackPreference:&k_EProvideDeckFeedbackPreference_Unset\x12\x1c\n\x14\x61\x64\x64itional_languages\x18\r \x01(\t\"\x91\x01\n\x19\x43Store_UserTagPreferences\x12\x37\n\x0ftags_to_exclude\x18\x01 \x03(\x0b\x32\x1e.CStore_UserTagPreferences.Tag\x1a;\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0ftimestamp_added\x18\x03 \x01(\r\"\xd3\x01\n#CStore_GetStorePreferences_Response\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12I\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32!.UserContentDescriptorPreferences\"W\n*CStore_GetTrendingAppsAmongFriends_Request\x12\x10\n\x08num_apps\x18\x01 \x01(\r\x12\x17\n\x0fnum_top_friends\x18\x02 \x01(\r\"\xd9\x01\n+CStore_GetTrendingAppsAmongFriends_Response\x12S\n\rtrending_apps\x18\x01 \x03(\x0b\x32<.CStore_GetTrendingAppsAmongFriends_Response.TrendingAppData\x1aU\n\x0fTrendingAppData\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1c\n\x14steamids_top_friends\x18\x02 \x03(\x04\x12\x15\n\rtotal_friends\x18\x03 \x01(\r\"\xbf\x01\n.CStore_MigratePartnerLinkTracking_Notification\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x11\n\tbrowserid\x18\x02 \x01(\x04\x12g\n\x0f\x62\x61\x63kfill_source\x18\x03 \x01(\x0e\x32#.EPartnerLinkTrackingBackfillSource:)k_EPartnerLinkTrackingBackfillSource_None\"|\n(CStore_UpdatePackageReservations_Request\x12\x1b\n\x13packages_to_reserve\x18\x01 \x03(\r\x12\x1d\n\x15packages_to_unreserve\x18\x02 \x03(\r\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\"c\n)CStore_UpdatePackageReservations_Response\x12\x36\n\x12reservation_status\x18\x01 \x03(\x0b\x32\x1a.CPackageReservationStatus\"i\n)CStore_GetWishlistDemoEmailStatus_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ndemo_appid\x18\x02 \x01(\r\x12\x19\n\x11\x61llow_late_firing\x18\x03 \x01(\x08\"u\n*CStore_GetWishlistDemoEmailStatus_Response\x12\x17\n\x08\x63\x61n_fire\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0btime_staged\x18\x02 \x01(\r\x12\x19\n\x11\x64\x65mo_release_date\x18\x03 \x01(\r\"k\n+CStore_QueueWishlistDemoEmailToFire_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ndemo_appid\x18\x02 \x01(\r\x12\x19\n\x11\x61llow_late_firing\x18\x03 \x01(\x08\".\n,CStore_QueueWishlistDemoEmailToFire_Response\"\xd9\x01\n\x1b\x43ReservationPositionMessage\x12\x14\n\x0c\x65\x64istributor\x18\x01 \x01(\r\x12\x1a\n\x12product_identifier\x18\x02 \x01(\t\x12\x1c\n\x14start_queue_position\x18\x03 \x01(\r\x12$\n\x1crtime_estimated_notification\x18\x04 \x01(\r\x12\x1a\n\x12localization_token\x18\x05 \x01(\t\x12\x11\n\taccountid\x18\x06 \x01(\r\x12\x15\n\rrtime_created\x18\x07 \x01(\r\"^\n,CStore_SetReservationPositionMessage_Request\x12.\n\x08settings\x18\x01 \x03(\x0b\x32\x1c.CReservationPositionMessage\"/\n-CStore_SetReservationPositionMessage_Response\"\x81\x01\n/CStore_DeleteReservationPositionMessage_Request\x12\x14\n\x0c\x65\x64istributor\x18\x01 \x01(\r\x12\x1a\n\x12product_identifier\x18\x02 \x01(\t\x12\x1c\n\x14start_queue_position\x18\x03 \x01(\r\"2\n0CStore_DeleteReservationPositionMessage_Response\"2\n0CStore_GetAllReservationPositionMessages_Request\"c\n1CStore_GetAllReservationPositionMessages_Response\x12.\n\x08settings\x18\x01 \x03(\x0b\x32\x1c.CReservationPositionMessage\":\n8CStore_ReloadAllReservationPositionMessages_Notification\"\x99\x01\n+CSteamDeckCompatibility_SetFeedback_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12[\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0e\x32 .ESteamDeckCompatibilityFeedback:\'k_ESteamDeckCompatibilityFeedback_Unset\".\n,CSteamDeckCompatibility_SetFeedback_Response\"=\n,CSteamDeckCompatibility_ShouldPrompt_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xc0\x01\n-CSteamDeckCompatibility_ShouldPrompt_Response\x12\x0e\n\x06prompt\x18\x01 \x01(\x08\x12\x19\n\x11\x66\x65\x65\x64\x62\x61\x63k_eligible\x18\x02 \x01(\x08\x12\x64\n\x11\x65xisting_feedback\x18\x03 \x01(\x0e\x32 .ESteamDeckCompatibilityFeedback:\'k_ESteamDeckCompatibilityFeedback_Unset\"\xdb\x01\n+CStore_StorePreferencesChanged_Notification\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12I\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32!.UserContentDescriptorPreferences*\xab\x05\n\x18\x45StoreDiscoveryQueueType\x12!\n\x1dk_EStoreDiscoveryQueueTypeNew\x10\x00\x12(\n$k_EStoreDiscoveryQueueTypeComingSoon\x10\x01\x12)\n%k_EStoreDiscoveryQueueTypeRecommended\x10\x02\x12-\n)k_EStoreDiscoveryQueueTypeEveryNewRelease\x10\x03\x12+\n\'k_EStoreDiscoveryQueueTypeMLRecommender\x10\x05\x12,\n(k_EStoreDiscoveryQueueTypeWishlistOnSale\x10\x06\x12!\n\x1dk_EStoreDiscoveryQueueTypeDLC\x10\x07\x12\'\n#k_EStoreDiscoveryQueueTypeDLCOnSale\x10\x08\x12\x33\n/k_EStoreDiscoveryQueueTypeRecommendedComingSoon\x10\t\x12-\n)k_EStoreDiscoveryQueueTypeRecommendedFree\x10\n\x12/\n+k_EStoreDiscoveryQueueTypeRecommendedOnSale\x10\x0b\x12.\n*k_EStoreDiscoveryQueueTypeRecommendedDemos\x10\x0c\x12,\n(k_EStoreDiscoveryQueueTypeDLCNewReleases\x10\r\x12+\n\'k_EStoreDiscoveryQueueTypeDLCTopSellers\x10\x0e\x12!\n\x1dk_EStoreDiscoveryQueueTypeMAX\x10\x0f*\x9a\x01\n\x0f\x45PlaytestStatus\x12\x17\n\x13k_ETesterStatusNone\x10\x00\x12\x1a\n\x16k_ETesterStatusPending\x10\x01\x12\x1a\n\x16k_ETesterStatusInvited\x10\x02\x12\x1a\n\x16k_ETesterStatusGranted\x10\x03\x12\x1a\n\x16k_ETesterStatusExpired\x10\x04*\xa2\x04\n\x0e\x45\x41ppReportType\x12\x1c\n\x18k_EAppReportType_Invalid\x10\x00\x12\x19\n\x15k_EAppReportType_Scam\x10\x01\x12\x1c\n\x18k_EAppReportType_Malware\x10\x02\x12\x1f\n\x1bk_EAppReportType_HateSpeech\x10\x03\x12 \n\x1ck_EAppReportType_Pornography\x10\x04\x12+\n\'k_EAppReportType_NonLabeledAdultContent\x10\x05\x12\x1d\n\x19k_EAppReportType_Libelous\x10\x06\x12\x1e\n\x1ak_EAppReportType_Offensive\x10\x07\x12%\n!k_EAppReportType_ExploitsChildren\x10\x08\x12\x38\n4k_EAppReportType_MtxWithNonSteamWalletPaymentMethods\x10\t\x12\'\n#k_EAppReportType_CopyrightViolation\x10\n\x12!\n\x1dk_EAppReportType_ViolatesLaws\x10\x0b\x12\x1a\n\x16k_EAppReportType_Other\x10\x0c\x12\x1b\n\x17k_EAppReportType_Broken\x10\r\x12$\n k_EAppReportType_AIContentReport\x10\x0e*\xa0\x01\n\x1a\x45UserReviewScorePreference\x12&\n\"k_EUserReviewScorePreference_Unset\x10\x00\x12+\n\'k_EUserReviewScorePreference_IncludeAll\x10\x01\x12-\n)k_EUserReviewScorePreference_ExcludeBombs\x10\x02*\xe4\x01\n\"EPartnerLinkTrackingBackfillSource\x12-\n)k_EPartnerLinkTrackingBackfillSource_None\x10\x00\x12,\n(k_EPartnerLinkTrackingBackfillSource_Web\x10\x01\x12/\n+k_EPartnerLinkTrackingBackfillSource_Mobile\x10\x02\x12\x30\n,k_EPartnerLinkTrackingBackfillSource_Desktop\x10\x03\x32\xf4\x13\n\x05Store\x12N\n\rRegisterCDKey\x12\x1d.CStore_RegisterCDKey_Request\x1a\x1e.CStore_RegisterCDKey_Response\x12r\n\x19GetRecommendedTagsForUser\x12).CStore_GetRecommendedTagsForUser_Request\x1a*.CStore_GetRecommendedTagsForUser_Response\x12]\n\x12GetMostPopularTags\x12\".CStore_GetMostPopularTags_Request\x1a#.CStore_GetMostPopularTags_Response\x12l\n\x17GetLocalizedNameForTags\x12\'.CStore_GetLocalizedNameForTags_Request\x1a(.CStore_GetLocalizedNameForTags_Response\x12\x45\n\nGetTagList\x12\x1a.CStore_GetTagList_Request\x1a\x1b.CStore_GetTagList_Response\x12Z\n\x11GetDiscoveryQueue\x12!.CStore_GetDiscoveryQueue_Request\x1a\".CStore_GetDiscoveryQueue_Response\x12r\n\x19GetDiscoveryQueueSettings\x12).CStore_GetDiscoveryQueueSettings_Request\x1a*.CStore_GetDiscoveryQueueSettings_Response\x12i\n\x16SkipDiscoveryQueueItem\x12&.CStore_SkipDiscoveryQueueItem_Request\x1a\'.CStore_SkipDiscoveryQueueItem_Response\x12o\n\x18GetUserGameInterestState\x12(.CStore_GetUserGameInterestState_Request\x1a).CStore_GetUserGameInterestState_Response\x12{\n\x1cGetDiscoveryQueueSkippedApps\x12,.CStore_GetDiscoveryQueueSkippedApps_Request\x1a-.CStore_GetDiscoveryQueueSkippedApps_Response\x12\x42\n\tReportApp\x12\x19.CStore_ReportApp_Request\x1a\x1a.CStore_ReportApp_Response\x12`\n\x13GetStorePreferences\x12#.CStore_GetStorePreferences_Request\x1a$.CStore_GetStorePreferences_Response\x12x\n\x1bGetTrendingAppsAmongFriends\x12+.CStore_GetTrendingAppsAmongFriends_Request\x1a,.CStore_GetTrendingAppsAmongFriends_Response\x12Z\n\x1aMigratePartnerLinkTracking\x12/.CStore_MigratePartnerLinkTracking_Notification\x1a\x0b.NoResponse\x12r\n\x19UpdatePackageReservations\x12).CStore_UpdatePackageReservations_Request\x1a*.CStore_UpdatePackageReservations_Response\x12u\n\x1aGetWishlistDemoEmailStatus\x12*.CStore_GetWishlistDemoEmailStatus_Request\x1a+.CStore_GetWishlistDemoEmailStatus_Response\x12{\n\x1cQueueWishlistDemoEmailToFire\x12,.CStore_QueueWishlistDemoEmailToFire_Request\x1a-.CStore_QueueWishlistDemoEmailToFire_Response\x12~\n\x1dSetReservationPositionMessage\x12-.CStore_SetReservationPositionMessage_Request\x1a..CStore_SetReservationPositionMessage_Response\x12\x87\x01\n DeleteReservationPositionMessage\x12\x30.CStore_DeleteReservationPositionMessage_Request\x1a\x31.CStore_DeleteReservationPositionMessage_Response\x12\x8a\x01\n!GetAllReservationPositionMessages\x12\x31.CStore_GetAllReservationPositionMessages_Request\x1a\x32.CStore_GetAllReservationPositionMessages_Response\x12n\n$ReloadAllReservationPositionMessages\x12\x39.CStore_ReloadAllReservationPositionMessages_Notification\x1a\x0b.NoResponse\x12w\n\x18SetCompatibilityFeedback\x12,.CSteamDeckCompatibility_SetFeedback_Request\x1a-.CSteamDeckCompatibility_SetFeedback_Response\x12\x85\x01\n$ShouldPromptForCompatibilityFeedback\x12-.CSteamDeckCompatibility_ShouldPrompt_Request\x1a..CSteamDeckCompatibility_ShouldPrompt_Response2o\n\x0bStoreClient\x12Z\n\x1dNotifyStorePreferencesChanged\x12,.CStore_StorePreferencesChanged_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_store_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _STORECLIENT._options = None
  _STORECLIENT._serialized_options = b'\300\265\030\002'
  _ESTOREDISCOVERYQUEUETYPE._serialized_start=8101
  _ESTOREDISCOVERYQUEUETYPE._serialized_end=8784
  _EPLAYTESTSTATUS._serialized_start=8787
  _EPLAYTESTSTATUS._serialized_end=8941
  _EAPPREPORTTYPE._serialized_start=8944
  _EAPPREPORTTYPE._serialized_end=9490
  _EUSERREVIEWSCOREPREFERENCE._serialized_start=9493
  _EUSERREVIEWSCOREPREFERENCE._serialized_end=9653
  _EPARTNERLINKTRACKINGBACKFILLSOURCE._serialized_start=9656
  _EPARTNERLINKTRACKINGBACKFILLSOURCE._serialized_end=9884
  _CSTORE_REGISTERCDKEY_REQUEST._serialized_start=154
  _CSTORE_REGISTERCDKEY_REQUEST._serialized_end=268
  _CSTORE_PURCHASERECEIPTINFO._serialized_start=271
  _CSTORE_PURCHASERECEIPTINFO._serialized_end=810
  _CSTORE_PURCHASERECEIPTINFO_LINEITEM._serialized_start=735
  _CSTORE_PURCHASERECEIPTINFO_LINEITEM._serialized_end=810
  _CSTORE_REGISTERCDKEY_RESPONSE._serialized_start=812
  _CSTORE_REGISTERCDKEY_RESPONSE._serialized_end=936
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_REQUEST._serialized_start=938
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_REQUEST._serialized_end=1046
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_RESPONSE._serialized_start=1049
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_RESPONSE._serialized_end=1206
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_RESPONSE_TAG._serialized_start=1156
  _CSTORE_GETRECOMMENDEDTAGSFORUSER_RESPONSE_TAG._serialized_end=1206
  _CSTORE_GETMOSTPOPULARTAGS_REQUEST._serialized_start=1208
  _CSTORE_GETMOSTPOPULARTAGS_REQUEST._serialized_end=1261
  _CSTORE_GETMOSTPOPULARTAGS_RESPONSE._serialized_start=1263
  _CSTORE_GETMOSTPOPULARTAGS_RESPONSE._serialized_end=1390
  _CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG._serialized_start=1156
  _CSTORE_GETMOSTPOPULARTAGS_RESPONSE_TAG._serialized_end=1190
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST._serialized_start=1392
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST._serialized_end=1466
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE._serialized_start=1469
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE._serialized_end=1653
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG._serialized_start=1572
  _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG._serialized_end=1653
  _CSTORE_GETTAGLIST_REQUEST._serialized_start=1655
  _CSTORE_GETTAGLIST_REQUEST._serialized_end=1727
  _CSTORE_GETTAGLIST_RESPONSE._serialized_start=1730
  _CSTORE_GETTAGLIST_RESPONSE._serialized_end=1863
  _CSTORE_GETTAGLIST_RESPONSE_TAG._serialized_start=1156
  _CSTORE_GETTAGLIST_RESPONSE_TAG._serialized_end=1190
  _CSTOREDISCOVERYQUEUESETTINGS._serialized_start=1866
  _CSTOREDISCOVERYQUEUESETTINGS._serialized_end=2221
  _CSTORE_GETDISCOVERYQUEUE_REQUEST._serialized_start=2224
  _CSTORE_GETDISCOVERYQUEUE_REQUEST._serialized_end=2748
  _CSTORE_GETDISCOVERYQUEUE_RESPONSE._serialized_start=2751
  _CSTORE_GETDISCOVERYQUEUE_RESPONSE._serialized_end=2997
  _CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST._serialized_start=3000
  _CSTORE_GETDISCOVERYQUEUESETTINGS_REQUEST._serialized_end=3166
  _CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE._serialized_start=3168
  _CSTORE_GETDISCOVERYQUEUESETTINGS_RESPONSE._serialized_end=3282
  _CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST._serialized_start=3285
  _CSTORE_SKIPDISCOVERYQUEUEITEM_REQUEST._serialized_end=3463
  _CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE._serialized_start=3465
  _CSTORE_SKIPDISCOVERYQUEUEITEM_RESPONSE._serialized_end=3505
  _CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST._serialized_start=3507
  _CSTORE_GETUSERGAMEINTERESTSTATE_REQUEST._serialized_end=3604
  _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE._serialized_start=3607
  _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE._serialized_end=4233
  _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE._serialized_start=4061
  _CSTORE_GETUSERGAMEINTERESTSTATE_RESPONSE_INQUEUE._serialized_end=4233
  _CSTORE_GETDISCOVERYQUEUESKIPPEDAPPS_REQUEST._serialized_start=4236
  _CSTORE_GETDISCOVERYQUEUESKIPPEDAPPS_REQUEST._serialized_end=4422
  _CSTORE_GETDISCOVERYQUEUESKIPPEDAPPS_RESPONSE._serialized_start=4424
  _CSTORE_GETDISCOVERYQUEUESKIPPEDAPPS_RESPONSE._serialized_end=4486
  _CSTORE_REPORTAPP_REQUEST._serialized_start=4488
  _CSTORE_REPORTAPP_REQUEST._serialized_end=4609
  _CSTORE_REPORTAPP_RESPONSE._serialized_start=4611
  _CSTORE_REPORTAPP_RESPONSE._serialized_end=4638
  _CSTORE_GETSTOREPREFERENCES_REQUEST._serialized_start=4640
  _CSTORE_GETSTOREPREFERENCES_REQUEST._serialized_end=4676
  _CSTORE_USERPREFERENCES._serialized_start=4679
  _CSTORE_USERPREFERENCES._serialized_end=5177
  _CSTORE_USERTAGPREFERENCES._serialized_start=5180
  _CSTORE_USERTAGPREFERENCES._serialized_end=5325
  _CSTORE_USERTAGPREFERENCES_TAG._serialized_start=5266
  _CSTORE_USERTAGPREFERENCES_TAG._serialized_end=5325
  _CSTORE_GETSTOREPREFERENCES_RESPONSE._serialized_start=5328
  _CSTORE_GETSTOREPREFERENCES_RESPONSE._serialized_end=5539
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST._serialized_start=5541
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_REQUEST._serialized_end=5628
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE._serialized_start=5631
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE._serialized_end=5848
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA._serialized_start=5763
  _CSTORE_GETTRENDINGAPPSAMONGFRIENDS_RESPONSE_TRENDINGAPPDATA._serialized_end=5848
  _CSTORE_MIGRATEPARTNERLINKTRACKING_NOTIFICATION._serialized_start=5851
  _CSTORE_MIGRATEPARTNERLINKTRACKING_NOTIFICATION._serialized_end=6042
  _CSTORE_UPDATEPACKAGERESERVATIONS_REQUEST._serialized_start=6044
  _CSTORE_UPDATEPACKAGERESERVATIONS_REQUEST._serialized_end=6168
  _CSTORE_UPDATEPACKAGERESERVATIONS_RESPONSE._serialized_start=6170
  _CSTORE_UPDATEPACKAGERESERVATIONS_RESPONSE._serialized_end=6269
  _CSTORE_GETWISHLISTDEMOEMAILSTATUS_REQUEST._serialized_start=6271
  _CSTORE_GETWISHLISTDEMOEMAILSTATUS_REQUEST._serialized_end=6376
  _CSTORE_GETWISHLISTDEMOEMAILSTATUS_RESPONSE._serialized_start=6378
  _CSTORE_GETWISHLISTDEMOEMAILSTATUS_RESPONSE._serialized_end=6495
  _CSTORE_QUEUEWISHLISTDEMOEMAILTOFIRE_REQUEST._serialized_start=6497
  _CSTORE_QUEUEWISHLISTDEMOEMAILTOFIRE_REQUEST._serialized_end=6604
  _CSTORE_QUEUEWISHLISTDEMOEMAILTOFIRE_RESPONSE._serialized_start=6606
  _CSTORE_QUEUEWISHLISTDEMOEMAILTOFIRE_RESPONSE._serialized_end=6652
  _CRESERVATIONPOSITIONMESSAGE._serialized_start=6655
  _CRESERVATIONPOSITIONMESSAGE._serialized_end=6872
  _CSTORE_SETRESERVATIONPOSITIONMESSAGE_REQUEST._serialized_start=6874
  _CSTORE_SETRESERVATIONPOSITIONMESSAGE_REQUEST._serialized_end=6968
  _CSTORE_SETRESERVATIONPOSITIONMESSAGE_RESPONSE._serialized_start=6970
  _CSTORE_SETRESERVATIONPOSITIONMESSAGE_RESPONSE._serialized_end=7017
  _CSTORE_DELETERESERVATIONPOSITIONMESSAGE_REQUEST._serialized_start=7020
  _CSTORE_DELETERESERVATIONPOSITIONMESSAGE_REQUEST._serialized_end=7149
  _CSTORE_DELETERESERVATIONPOSITIONMESSAGE_RESPONSE._serialized_start=7151
  _CSTORE_DELETERESERVATIONPOSITIONMESSAGE_RESPONSE._serialized_end=7201
  _CSTORE_GETALLRESERVATIONPOSITIONMESSAGES_REQUEST._serialized_start=7203
  _CSTORE_GETALLRESERVATIONPOSITIONMESSAGES_REQUEST._serialized_end=7253
  _CSTORE_GETALLRESERVATIONPOSITIONMESSAGES_RESPONSE._serialized_start=7255
  _CSTORE_GETALLRESERVATIONPOSITIONMESSAGES_RESPONSE._serialized_end=7354
  _CSTORE_RELOADALLRESERVATIONPOSITIONMESSAGES_NOTIFICATION._serialized_start=7356
  _CSTORE_RELOADALLRESERVATIONPOSITIONMESSAGES_NOTIFICATION._serialized_end=7414
  _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST._serialized_start=7417
  _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_REQUEST._serialized_end=7570
  _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE._serialized_start=7572
  _CSTEAMDECKCOMPATIBILITY_SETFEEDBACK_RESPONSE._serialized_end=7618
  _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST._serialized_start=7620
  _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_REQUEST._serialized_end=7681
  _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE._serialized_start=7684
  _CSTEAMDECKCOMPATIBILITY_SHOULDPROMPT_RESPONSE._serialized_end=7876
  _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION._serialized_start=7879
  _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION._serialized_end=8098
  _STORE._serialized_start=9887
  _STORE._serialized_end=12435
  _STORECLIENT._serialized_start=12437
  _STORECLIENT._serialized_end=12548
_builder.BuildServices(DESCRIPTOR, 'steammessages_store_pb2', globals())
# @@protoc_insertion_point(module_scope)
